@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2000, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2000, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -60,13 +60,37 @@ public final class StackTraceElement implements java.io.Serializable {
     private transient Class<?> declaringClassObject;
 
     // Normally initialized by VM
+    /**
+     * The name of the class loader.
+     */
     private String classLoaderName;
+    /**
+     * The module name.
+     */
     private String moduleName;
+    /**
+     * The module version.
+     */
     private String moduleVersion;
+    /**
+     * The declaring class.
+     */
     private String declaringClass;
+    /**
+     * The method name.
+     */
     private String methodName;
+    /**
+     * The source file name.
+     */
     private String fileName;
+    /**
+     * The source line number.
+     */
     private int    lineNumber;
+    /**
+     * Control to show full or partial module, package, and class names.
+     */
     private byte   format = 0; // Default to show all
 
     /**
@@ -91,7 +115,6 @@ public final class StackTraceElement implements java.io.Serializable {
      *         {@code methodName} is null
      * @since 1.5
      * @revised 9
-     * @spec JPMS
      */
     public StackTraceElement(String declaringClass, String methodName,
                              String fileName, int lineNumber) {
@@ -128,7 +151,6 @@ public final class StackTraceElement implements java.io.Serializable {
      *         or {@code methodName} is {@code null}
      *
      * @since 9
-     * @spec JPMS
      */
     public StackTraceElement(String classLoaderName,
                              String moduleName, String moduleVersion,
@@ -153,8 +175,8 @@ public final class StackTraceElement implements java.io.Serializable {
      * Returns the name of the source file containing the execution point
      * represented by this stack trace element.  Generally, this corresponds
      * to the {@code SourceFile} attribute of the relevant {@code class}
-     * file (as per <i>The Java Virtual Machine Specification</i>, Section
-     * 4.7.7).  In some systems, the name may refer to some source code unit
+     * file (as per <cite>The Java Virtual Machine Specification</cite>, Section
+     * {@jvms 4.7.7}).  In some systems, the name may refer to some source code unit
      * other than a file, such as an entry in source repository.
      *
      * @return the name of the file containing the execution point
@@ -169,8 +191,8 @@ public final class StackTraceElement implements java.io.Serializable {
      * Returns the line number of the source line containing the execution
      * point represented by this stack trace element.  Generally, this is
      * derived from the {@code LineNumberTable} attribute of the relevant
-     * {@code class} file (as per <i>The Java Virtual Machine
-     * Specification</i>, Section 4.7.8).
+     * {@code class} file (as per <cite>The Java Virtual Machine
+     * Specification</cite>, Section {@jvms 4.7.8}).
      *
      * @return the line number of the source line containing the execution
      *         point represented by this stack trace element, or a negative
@@ -188,7 +210,6 @@ public final class StackTraceElement implements java.io.Serializable {
      *         point represented by this stack trace element; {@code null}
      *         if the module name is not available.
      * @since 9
-     * @spec JPMS
      * @see Module#getName()
      */
     public String getModuleName() {
@@ -203,7 +224,6 @@ public final class StackTraceElement implements java.io.Serializable {
      *         point represented by this stack trace element; {@code null}
      *         if the module version is not available.
      * @since 9
-     * @spec JPMS
      * @see java.lang.module.ModuleDescriptor.Version
      */
     public String getModuleVersion() {
@@ -219,7 +239,6 @@ public final class StackTraceElement implements java.io.Serializable {
      *         if the class loader is not named.
      *
      * @since 9
-     * @spec JPMS
      * @see java.lang.ClassLoader#getName()
      */
     public String getClassLoaderName() {
@@ -242,8 +261,8 @@ public final class StackTraceElement implements java.io.Serializable {
      * represented by this stack trace element.  If the execution point is
      * contained in an instance or class initializer, this method will return
      * the appropriate <i>special method name</i>, {@code <init>} or
-     * {@code <clinit>}, as per Section 3.9 of <i>The Java Virtual
-     * Machine Specification</i>.
+     * {@code <clinit>}, as per Section {@jvms 3.9} of <cite>The Java Virtual
+     * Machine Specification</cite>.
      *
      * @return the name of the method containing the execution point
      *         represented by this stack trace element.
@@ -302,7 +321,7 @@ public final class StackTraceElement implements java.io.Serializable {
      * </ul>
      *
      * <p> The first example shows a stack trace element consisting of
-     * three elements, each separated by {@code "/"} followed with
+     * three elements, each separated by {@code "/"}, followed by
      * the source file name and the line number of the source line
      * containing the execution point.
      *
@@ -334,7 +353,6 @@ public final class StackTraceElement implements java.io.Serializable {
      * choose to omit some element in the returned string.
      *
      * @revised 9
-     * @spec JPMS
      * @see    Throwable#printStackTrace()
      */
     public String toString() {
@@ -384,21 +402,18 @@ public final class StackTraceElement implements java.io.Serializable {
      *         execution point as this instance.
      *
      * @revised 9
-     * @spec JPMS
      */
     public boolean equals(Object obj) {
         if (obj==this)
             return true;
-        if (!(obj instanceof StackTraceElement))
-            return false;
-        StackTraceElement e = (StackTraceElement)obj;
-        return Objects.equals(classLoaderName, e.classLoaderName) &&
-            Objects.equals(moduleName, e.moduleName) &&
-            Objects.equals(moduleVersion, e.moduleVersion) &&
-            e.declaringClass.equals(declaringClass) &&
-            e.lineNumber == lineNumber &&
-            Objects.equals(methodName, e.methodName) &&
-            Objects.equals(fileName, e.fileName);
+        return (obj instanceof StackTraceElement e)
+                && e.lineNumber == lineNumber
+                && e.declaringClass.equals(declaringClass)
+                && Objects.equals(classLoaderName, e.classLoaderName)
+                && Objects.equals(moduleName, e.moduleName)
+                && Objects.equals(moduleVersion, e.moduleVersion)
+                && Objects.equals(methodName, e.methodName)
+                && Objects.equals(fileName, e.fileName);
     }
 
     /**
@@ -428,7 +443,7 @@ public final class StackTraceElement implements java.io.Serializable {
      */
     private synchronized void computeFormat() {
         try {
-            Class<?> cls = (Class<?>) declaringClassObject;
+            Class<?> cls = declaringClassObject;
             ClassLoader loader = cls.getClassLoader0();
             Module m = cls.getModule();
             byte bits = 0;
@@ -514,22 +529,17 @@ public final class StackTraceElement implements java.io.Serializable {
 
     /*
      * Returns an array of StackTraceElements of the given depth
-     * filled from the backtrace of a given Throwable.
+     * filled from the given backtrace.
      */
-    static StackTraceElement[] of(Throwable x, int depth) {
+    static StackTraceElement[] of(Object x, int depth) {
         StackTraceElement[] stackTrace = new StackTraceElement[depth];
         for (int i = 0; i < depth; i++) {
             stackTrace[i] = new StackTraceElement();
         }
 
         // VM to fill in StackTraceElement
-        initStackTraceElements(stackTrace, x);
-
-        // ensure the proper StackTraceElement initialization
-        for (StackTraceElement ste : stackTrace) {
-            ste.computeFormat();
-        }
-        return stackTrace;
+        initStackTraceElements(stackTrace, x, depth);
+        return of(stackTrace);
     }
 
     /*
@@ -543,12 +553,20 @@ public final class StackTraceElement implements java.io.Serializable {
         return ste;
     }
 
+    static StackTraceElement[] of(StackTraceElement[] stackTrace) {
+        // ensure the proper StackTraceElement initialization
+        for (StackTraceElement ste : stackTrace) {
+            ste.computeFormat();
+        }
+        return stackTrace;
+    }
+
     /*
      * Sets the given stack trace elements with the backtrace
      * of the given Throwable.
      */
     private static native void initStackTraceElements(StackTraceElement[] elements,
-                                                      Throwable x);
+                                                      Object x, int depth);
     /*
      * Sets the given stack trace element with the given StackFrameInfo
      */
