@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2017, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -34,6 +34,7 @@ import java.util.List;
 import java.util.Set;
 import java.util.concurrent.ConcurrentLinkedDeque;
 import java.util.concurrent.Executor;
+import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Flow;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicLong;
@@ -115,7 +116,7 @@ class Http1AsyncReceiver {
         public AbstractSubscription subscription();
 
         /**
-         * Called to make sure resources are released when the
+         * Called to make sure resources are released
          * when the Http1AsyncReceiver is stopped.
          * @param error The Http1AsyncReceiver pending error ref,
          *              if any.
@@ -166,7 +167,7 @@ class Http1AsyncReceiver {
     private final ConcurrentLinkedDeque<ByteBuffer> queue
             = new ConcurrentLinkedDeque<>();
     private final SequentialScheduler scheduler =
-            SequentialScheduler.synchronizedScheduler(this::flush);
+            SequentialScheduler.lockingScheduler(this::flush);
     final MinimalFuture<Void> whenFinished;
     private final Executor executor;
     private final Http1TubeSubscriber subscriber = new Http1TubeSubscriber();
@@ -199,7 +200,11 @@ class Http1AsyncReceiver {
     private void flush() {
         ByteBuffer buf;
         try {
-            assert !client.isSelectorThread() :
+            // we should not be running in the selector here,
+            // except if the custom Executor supplied to the client is
+            // something like (r) -> r.run();
+           assert !client.isSelectorThread()
+                   || !(client.theExecutor().delegate() instanceof ExecutorService) :
                     "Http1AsyncReceiver::flush should not run in the selector: "
                     + Thread.currentThread().getName();
 
@@ -473,7 +478,7 @@ class Http1AsyncReceiver {
                 // the pool.
                 if (retry && (ex instanceof IOException)) {
                     // could be either EOFException, or
-                    // IOException("connection reset by peer), or
+                    // IOException("connection reset by peer"), or
                     // SSLHandshakeException resulting from the server having
                     // closed the SSL session.
                     if (received.get() == 0) {
@@ -492,7 +497,8 @@ class Http1AsyncReceiver {
         final Throwable t = (recorded == null ? ex : recorded);
         if (debug.on())
             debug.log("recorded " + t + "\n\t delegate: " + delegate
-                      + "\t\t queue.isEmpty: " + queue.isEmpty(), ex);
+                      + "\n\t queue.isEmpty: " + queue.isEmpty()
+                      + "\n\tstopRequested: " + stopRequested, ex);
         if (Log.errors()) {
             Log.logError("HTTP/1 read subscriber recorded error: {0} - {1}", describe(), t);
         }
@@ -704,7 +710,7 @@ class Http1AsyncReceiver {
         for (ByteBuffer b : lbb) {
             if (!sbb.remove(b)) {
                 msg.append(sep)
-                   .append(String.valueOf(b))
+                   .append(b)
                    .append("[remaining=")
                    .append(b.remaining())
                    .append(", position=")
@@ -722,14 +728,12 @@ class Http1AsyncReceiver {
     String dbgString() {
         String tag = dbgTag;
         if (tag == null) {
-            String flowTag = null;
             Http1Exchange<?> exchg = owner;
             Object flow = (exchg != null)
                     ? exchg.connection().getConnectionFlow()
                     : null;
-            flowTag = tag = flow == null ? null: (String.valueOf(flow));
-            if (flowTag != null) {
-                dbgTag = tag = "Http1AsyncReceiver("+ flowTag + ")";
+            if (flow != null) {
+                dbgTag = tag = "Http1AsyncReceiver(" + flow + ")";
             } else {
                 tag = "Http1AsyncReceiver(?)";
             }
