@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2015, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -23,14 +23,6 @@
  * questions.
  */
 
-/**
- *  A utility class.
- *
- *  <p><b>This is NOT part of any supported API.
- *  If you write code that depends on this, you do so at your own risk.
- *  This code and its internal interfaces are subject to change or
- *  deletion without notice.</b>
- */
 
 package jdk.javadoc.internal.doclets.toolkit;
 
@@ -57,9 +49,13 @@ import com.sun.source.doctree.AttributeTree;
 import com.sun.source.doctree.DocCommentTree;
 import com.sun.source.doctree.DocTree;
 import com.sun.source.doctree.IdentifierTree;
+import com.sun.source.doctree.LiteralTree;
 import com.sun.source.doctree.ParamTree;
 import com.sun.source.doctree.ReferenceTree;
+import com.sun.source.doctree.ReturnTree;
+import com.sun.source.doctree.SinceTree;
 import com.sun.source.doctree.TextTree;
+import com.sun.source.doctree.UnknownBlockTagTree;
 import com.sun.source.util.DocTreeFactory;
 import com.sun.source.util.DocTreePath;
 import com.sun.source.util.DocTrees;
@@ -67,52 +63,61 @@ import com.sun.source.util.TreePath;
 import com.sun.tools.javac.util.DefinedBy;
 import com.sun.tools.javac.util.DefinedBy.Api;
 import jdk.javadoc.internal.doclets.toolkit.util.Utils;
+import jdk.javadoc.internal.doclets.toolkit.util.VisibleMemberTable;
 
+/**
+ * A utility class for handling documentation comments.
+ */
 public class CommentUtils {
 
     final BaseConfiguration configuration;
     final Utils utils;
     final Resources resources;
     final DocTreeFactory treeFactory;
-    final HashMap<Element, DocCommentDuo> dcTreesMap = new HashMap<>();
     final DocTrees trees;
     final Elements elementUtils;
 
+    /**
+     * A map for storing automatically generated comments for various
+     * elements, such as mandated elements (Enum.values, Enum.valueOf, etc)
+     * and JavaFX properties.
+     *
+     * @see Utils#dcTreeCache
+     */
+    final HashMap<Element, DocCommentInfo> dcInfoMap = new HashMap<>();
+
     protected CommentUtils(BaseConfiguration configuration) {
         this.configuration = configuration;
         utils = configuration.utils;
-        resources = configuration.getResources();
+        resources = configuration.getDocResources();
         trees = configuration.docEnv.getDocTrees();
         treeFactory = trees.getDocTreeFactory();
         elementUtils = configuration.docEnv.getElementUtils();
     }
 
     public List<? extends DocTree> makePropertyDescriptionTree(List<? extends DocTree> content) {
-        List<DocTree> out = new ArrayList<>();
         Name name = elementUtils.getName("propertyDescription");
-        out.add(treeFactory.newUnknownBlockTagTree(name, content));
-        return out;
+        return List.of(treeFactory.newUnknownBlockTagTree(name, content));
     }
 
-    public List<? extends DocTree> makePropertyDescriptionTree(String content) {
-        List<DocTree> inlist = new ArrayList<>();
-        inlist.add(treeFactory.newCommentTree(content));
-        List<DocTree> out = new ArrayList<>();
-        Name name = elementUtils.getName("propertyDescription");
-        out.add(treeFactory.newUnknownBlockTagTree(name, inlist));
-        return out;
+    public LiteralTree makeCodeTree(String text) {
+        return treeFactory.newCodeTree(makeTextTree(text));
     }
 
     public List<? extends DocTree> makeFirstSentenceTree(String content) {
-        List<DocTree> out = new ArrayList<>();
-        out.add(treeFactory.newTextTree(content));
-        return out;
+        return List.of(treeFactory.newTextTree(content));
+    }
+
+    public ParamTree makeParamTree(Name name, List<? extends DocTree> description) {
+        return treeFactory.newParamTree(false, treeFactory.newIdentifierTree(name), description);
+    }
+
+    public ReturnTree makeReturnTree(List<? extends DocTree> description) {
+        return treeFactory.newReturnTree(false, description);
     }
 
     public DocTree makeSeeTree(String sig, Element e) {
-        List<DocTree> list = new ArrayList<>();
-        list.add(treeFactory.newReferenceTree(sig));
-        return treeFactory.newSeeTree(list);
+        return treeFactory.newSeeTree(List.of(treeFactory.newReferenceTree(sig)));
     }
 
     public TextTree makeTextTree(String content) {
@@ -133,7 +138,7 @@ public class CommentUtils {
         List<DocTree> tags = new ArrayList<>();
         tags.add(treeFactory.newReturnTree(descriptions));
         DocCommentTree docTree = treeFactory.newDocCommentTree(fullBody, tags);
-        dcTreesMap.put(ee, new DocCommentDuo(null, docTree));
+        dcInfoMap.put(ee, new DocCommentInfo(null, docTree));
     }
 
     public void setEnumValueOfTree(ExecutableElement ee) {
@@ -167,7 +172,7 @@ public class CommentUtils {
 
         DocCommentTree docTree = treeFactory.newDocCommentTree(fullBody, tags);
 
-        dcTreesMap.put(ee, new DocCommentDuo(null, docTree));
+        dcInfoMap.put(ee, new DocCommentInfo(null, docTree));
     }
 
     /**
@@ -181,7 +186,6 @@ public class CommentUtils {
                 makeDescriptionWithName("doclet.record_constructor_doc.fullbody", te.getSimpleName());
 
         List<DocTree> tags = new ArrayList<>();
-        java.util.List<? extends VariableElement> parameters = ee.getParameters();
         for (VariableElement param : ee.getParameters()) {
             Name name = param.getSimpleName();
             IdentifierTree id = treeFactory.newIdentifierTree(name);
@@ -190,14 +194,13 @@ public class CommentUtils {
         }
 
         DocCommentTree docTree = treeFactory.newDocCommentTree(fullBody, tags);
-        dcTreesMap.put(ee, new DocCommentDuo(null, docTree));
+        dcInfoMap.put(ee, new DocCommentInfo(null, docTree));
     }
 
     /**
      * Generates the description for the standard {@code equals} method for a record.
      * @param ee the {@code equals} method
      */
-    @SuppressWarnings("preview")
     public void setRecordEqualsTree(ExecutableElement ee) {
         List<DocTree> fullBody = new ArrayList<>();
         add(fullBody, "doclet.record_equals_doc.fullbody.head");
@@ -226,7 +229,7 @@ public class CommentUtils {
 
         TreePath treePath = utils.getTreePath(ee.getEnclosingElement());
         DocCommentTree docTree = treeFactory.newDocCommentTree(fullBody, List.of(paramTree, returnTree));
-        dcTreesMap.put(ee, new DocCommentDuo(treePath, docTree));
+        dcInfoMap.put(ee, new DocCommentInfo(treePath, docTree));
     }
 
     private void add(List<DocTree> contents, String resourceKey) {
@@ -262,7 +265,7 @@ public class CommentUtils {
                 List.of(makeTextTreeForResource("doclet.record_hashCode_doc.return")));
 
         DocCommentTree docTree = treeFactory.newDocCommentTree(fullBody, List.of(returnTree));
-        dcTreesMap.put(ee, new DocCommentDuo(null, docTree));
+        dcInfoMap.put(ee, new DocCommentInfo(null, docTree));
     }
 
     /**
@@ -277,7 +280,7 @@ public class CommentUtils {
                 treeFactory.newTextTree(resources.getText("doclet.record_toString_doc.return"))));
 
         DocCommentTree docTree = treeFactory.newDocCommentTree(fullBody, List.of(returnTree));
-        dcTreesMap.put(ee, new DocCommentDuo(null, docTree));
+        dcInfoMap.put(ee, new DocCommentInfo(null, docTree));
     }
 
     /**
@@ -294,7 +297,7 @@ public class CommentUtils {
                     makeDescriptionWithComponent("doclet.record_accessor_doc.return", te, ee.getSimpleName()));
 
         DocCommentTree docTree = treeFactory.newDocCommentTree(fullBody, List.of(returnTree));
-        dcTreesMap.put(ee, new DocCommentDuo(null, docTree));
+        dcInfoMap.put(ee, new DocCommentInfo(null, docTree));
     }
 
     /**
@@ -308,7 +311,108 @@ public class CommentUtils {
             makeDescriptionWithComponent("doclet.record_field_doc.fullbody", te, ve.getSimpleName());
 
         DocCommentTree docTree = treeFactory.newDocCommentTree(fullBody, List.of());
-        dcTreesMap.put(ve, new DocCommentDuo(null, docTree));
+        dcInfoMap.put(ve, new DocCommentInfo(null, docTree));
+    }
+
+
+    /**
+     * Update the property method, property setter and/or property getter
+     * comment text so that it contains the documentation from
+     * the preferred property description (field or property method).
+     * The method adds the leading sentence, copied documentation including
+     * the defaultValue tag and the {@code @see} tags if the appropriate methods are
+     * available.
+     *
+     * @param member the member which is to be augmented
+     * @param property the element containing the preferred property description
+     */
+    public void updatePropertyMethodComment(ExecutableElement member,
+                                 Element property) {
+        final String memberName = member.getSimpleName().toString();
+        final boolean isSetter = memberName.startsWith("set");
+        final boolean isGetter = memberName.startsWith("get") || memberName.startsWith("is");
+
+        List<DocTree> fullBody = new ArrayList<>();
+        List<DocTree> blockTags = new ArrayList<>();
+
+        if (isGetter || isSetter) {
+            DocTree propName = makeCodeTree(utils.propertyName(member));
+
+            if (isGetter) {
+                // Set the body and @return
+                fullBody.addAll(getComment("doclet.PropertyGetterWithName", propName));
+                blockTags.add(makeReturnTree(
+                        getComment("doclet.PropertyGetterReturn", propName)));
+            }
+
+            if (isSetter) {
+                // Set the body and @param
+                fullBody.addAll(getComment("doclet.PropertySetterWithName", propName));
+                VariableElement arg0 = member.getParameters().get(0);
+                blockTags.add(makeParamTree(arg0.getSimpleName(),
+                        getComment("doclet.PropertySetterParam", propName)));
+            }
+
+            // Set the @propertyDescription
+            List<? extends DocTree> propertyTags = utils.getBlockTags(property,
+                    t -> (t instanceof UnknownBlockTagTree tree)
+                            && (tree.getTagName().equals("propertyDescription")));
+            if (propertyTags.isEmpty()) {
+                List<? extends DocTree> comment = utils.getFullBody(property);
+                blockTags.addAll(makePropertyDescriptionTree(comment));
+            }
+        } else {
+            // property method
+            fullBody.addAll(utils.getFullBody(property));
+
+            // Set the @return
+            DocTree propName = makeCodeTree(configuration.propertyUtils.getBaseName(member));
+            List<? extends DocTree> returnTags = utils.getBlockTags(property, DocTree.Kind.RETURN);
+            if (returnTags.isEmpty()) {
+                blockTags.add(makeReturnTree(
+                        getComment("doclet.PropertyMethodReturn", propName)));
+            } else {
+                blockTags.addAll(returnTags);
+            }
+        }
+
+        // copy certain tags
+        List<? extends SinceTree> sinceTags = utils.getBlockTags(property, DocTree.Kind.SINCE, SinceTree.class);
+        blockTags.addAll(sinceTags);
+
+        List<? extends DocTree> bTags = utils.getBlockTags(property,
+                t -> (t instanceof UnknownBlockTagTree tree)
+                        && (tree.getTagName().equals("defaultValue")));
+        blockTags.addAll(bTags);
+
+        //add @see tags
+        TypeElement te = (TypeElement) member.getEnclosingElement();
+        VisibleMemberTable vmt = configuration.getVisibleMemberTable(te);
+        ExecutableElement getter = vmt.getPropertyGetter(member);
+        ExecutableElement setter = vmt.getPropertySetter(member);
+        ExecutableElement propMethod = vmt.getPropertyMethod(member);
+
+        if (getter != null && getter != member) {
+            String sig = "#" + getter.getSimpleName() + "()";
+            blockTags.add(makeSeeTree(sig, getter));
+        }
+
+        if (setter != null && setter != member) {
+            VariableElement param = setter.getParameters().get(0);
+            StringBuilder sb = new StringBuilder("#");
+            sb.append(setter.getSimpleName());
+            if (!utils.isTypeVariable(param.asType())) {
+                sb.append("(").append(utils.getTypeSignature(param.asType(), false, true)).append(")");
+            }
+            blockTags.add(makeSeeTree(sb.toString(), setter));
+        }
+
+        if (propMethod != member) {
+            String sig = "#" + propMethod.getSimpleName() + "()";
+            blockTags.add(makeSeeTree(sig, propMethod));
+        }
+
+        setDocCommentTree(member, fullBody, blockTags);
     }
 
     /**
@@ -361,7 +465,7 @@ public class CommentUtils {
         }
 
         for (DocTree t : elemComment.getBlockTags()) {
-            if (t instanceof ParamTree && ((ParamTree) t).getName().getName() == component) {
+            if (t instanceof ParamTree pt && pt.getName().getName() == component) {
                 return true;
             }
         }
@@ -394,30 +498,83 @@ public class CommentUtils {
         }
     }
 
-    /*
-     * Returns the TreePath/DocCommentTree duo for synthesized element.
+    /**
+     * {@return a list containing the string for a given key in the doclet's
+     * resources, formatted with given arguments}
+     *
+     * @param key the key for the desired string
+     * @param o0  string or DocTree argument to be formatted into the result
      */
-    public DocCommentDuo getSyntheticCommentDuo(Element e) {
-        return dcTreesMap.get(e);
+    public List<? extends DocTree> getComment(String key, Object o0) {
+        return getComment(key, o0, null, null);
+    }
+
+    /**
+     * {@return a list containing the string for a given key in the doclet's
+     * resources, formatted with given arguments}
+     *
+     * @param key the key for the desired strings
+     * @param o0  string or a DocTree argument to be formatted into the result
+     * @param o1  string or a DocTree argument to be formatted into the result
+     * @param o2  string or a DocTree argument to be formatted into the result
+     */
+    public List<? extends DocTree> getComment(String key, Object o0, Object o1, Object o2) {
+        List<DocTree> l = new ArrayList<>();
+        Pattern p = Pattern.compile("\\{([012])\\}");
+        String text = resources.getText(key);
+        Matcher m = p.matcher(text);
+        int start = 0;
+        while (m.find(start)) {
+            l.add(makeTextTree(text.substring(start, m.start())));
+
+            Object o = null;
+            switch (m.group(1).charAt(0)) {
+                case '0': o = o0; break;
+                case '1': o = o1; break;
+                case '2': o = o2; break;
+            }
+
+            if (o == null) {
+                l.add(makeTextTree("{" + m.group(1) + "}"));
+            } else if (o instanceof String str) {
+                l.add(makeTextTree(str));
+            } else if (o instanceof DocTree t) {
+                l.add(t);
+            }
+
+            start = m.end();
+        }
+
+        l.add(makeTextTree(text.substring(start)));
+        return l;
     }
 
     /*
-     * Returns the TreePath/DocCommentTree duo for html sources.
+     * Returns the TreePath/DocCommentTree info that has been generated for an element.
+     * @param e the element
+     * @return the info object containing the tree path and doc comment
      */
-    public DocCommentDuo getHtmlCommentDuo(Element e) {
+    // "synthetic" is not the best word here, and should not be confused with synthetic elements
+    public DocCommentInfo getSyntheticCommentInfo(Element e) {
+        return dcInfoMap.get(e);
+    }
+
+    /*
+     * Returns the TreePath/DocCommentTree info for HTML sources.
+     */
+    public DocCommentInfo getHtmlCommentInfo(Element e) {
         FileObject fo = null;
         PackageElement pe = null;
         switch (e.getKind()) {
             case OTHER:
-                if (e instanceof DocletElement) {
-                    DocletElement de = (DocletElement)e;
+                if (e instanceof DocletElement de) {
                     fo = de.getFileObject();
                     pe = de.getPackageElement();
                 }
                 break;
             case PACKAGE:
-                fo = configuration.workArounds.getJavaFileObject((PackageElement)e);
-                pe = (PackageElement)e;
+                pe = (PackageElement) e;
+                fo = configuration.workArounds.getJavaFileObject(pe);
                 break;
             default:
                 return null;
@@ -431,7 +588,7 @@ public class CommentUtils {
             return null;
         }
         DocTreePath treePath = trees.getDocTreePath(fo, pe);
-        return new DocCommentDuo(treePath.getTreePath(), dcTree);
+        return new DocCommentInfo(treePath.getTreePath(), dcTree);
     }
 
     public DocCommentTree parse(URI uri, String text) {
@@ -444,27 +601,42 @@ public class CommentUtils {
         });
     }
 
-    public void setDocCommentTree(Element element, List<? extends DocTree> fullBody,
+    public DocCommentInfo setDocCommentTree(Element element, List<? extends DocTree> fullBody,
                                   List<? extends DocTree> blockTags) {
         DocCommentTree docTree = treeFactory.newDocCommentTree(fullBody, blockTags);
-        dcTreesMap.put(element, new DocCommentDuo(null, docTree));
+        return setDocCommentInfo(element, new DocCommentInfo(null, docTree));
+    }
+
+    public DocCommentInfo setDocCommentInfo(Element element, DocCommentInfo dci) {
+        DocCommentInfo prev = dcInfoMap.put(element, dci);
         // A method having null comment (no comment) that might need to be replaced
-        // with a synthetic comment, remove such a comment from the cache.
+        // with a generated comment, remove such a comment from the cache.
         utils.removeCommentHelper(element);
+        return prev;
     }
 
     /**
-     * A simplistic container to transport a TreePath, DocCommentTree pair.
-     * Here is why we need this:
-     * a. not desirable to add javac's pair.
-     * b. DocTreePath is not a viable  option either, as a null TreePath is required
-     * to represent synthetic comments for Enum.values, valuesOf, javafx properties.
+     * Info about a doc comment:
+     *   the position in the enclosing AST, and
+     *   the parsed doc comment itself.
+     *
+     * The position in the AST is {@code null} for automatically generated comments,
+     * such as for {@code Enum.values}, {@code Enum.valuesOf}, and JavaFX properties.
      */
-    public static class DocCommentDuo {
+    public static class DocCommentInfo {
+        /**
+         * The position of the comment in the enclosing AST, or {@code null}
+         * for automatically generated comments.
+         */
         public final TreePath treePath;
+
+        /**
+         * The doc comment tree that is the root node of a parsed doc comment,
+         * or {@code null} if there is no comment.
+         */
         public final DocCommentTree dcTree;
 
-        public DocCommentDuo(TreePath treePath, DocCommentTree dcTree) {
+        public DocCommentInfo(TreePath treePath, DocCommentTree dcTree) {
             this.treePath = treePath;
             this.dcTree = dcTree;
         }
