@@ -4,15 +4,17 @@ public final class doclets_zh_CN extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
             { "doclet.Abstract_Methods", "\u62BD\u8C61\u65B9\u6CD5" },
-            { "doclet.All_Classes", "\u6240\u6709\u7C7B" },
+            { "doclet.All_Classes_And_Interfaces", "\u6240\u6709\u7C7B\u548C\u63A5\u53E3" },
             { "doclet.All_Implemented_Interfaces", "\u6240\u6709\u5DF2\u5B9E\u73B0\u7684\u63A5\u53E3:" },
             { "doclet.All_Methods", "\u6240\u6709\u65B9\u6CD5" },
             { "doclet.All_Modules", "\u5168\u90E8\u6A21\u5757" },
             { "doclet.All_Packages", "\u6240\u6709\u7A0B\u5E8F\u5305" },
             { "doclet.All_Superinterfaces", "\u6240\u6709\u8D85\u7EA7\u63A5\u53E3:" },
-            { "doclet.All_classes_and_interfaces", "\u6240\u6709\u7C7B\u548C\u63A5\u53E3 (\u9664\u4E86\u975E\u9759\u6001\u5D4C\u5957\u7C7B\u578B)" },
+            { "doclet.AnnotationInterface", "\u6CE8\u91CA\u63A5\u53E3" },
+            { "doclet.AnnotationInterfaces", "\u6CE8\u91CA\u63A5\u53E3" },
             { "doclet.AnnotationType", "\u6CE8\u91CA\u7C7B\u578B" },
             { "doclet.AnnotationTypes", "\u6CE8\u91CA\u7C7B\u578B" },
+            { "doclet.Annotation_Interface_Member", "\u6CE8\u91CA\u63A5\u53E3\u5143\u7D20" },
             { "doclet.Annotation_Type_Member", "\u6CE8\u91CA\u7C7B\u578B\u5143\u7D20" },
             { "doclet.Annotation_Type_Member_Detail", "\u5143\u7D20\u8BE6\u7EC6\u8D44\u6599" },
             { "doclet.Annotation_Type_Optional_Member", "\u53EF\u9009\u5143\u7D20" },
@@ -21,26 +23,24 @@ public final class doclets_zh_CN extends java.util.ListResourceBundle {
             { "doclet.Annotation_Type_Required_Member", "\u5FC5\u9700\u7684\u5143\u7D20" },
             { "doclet.Annotation_Type_Required_Member_Summary", "\u5FC5\u9700\u5143\u7D20\u6982\u8981" },
             { "doclet.Annotation_Type_Required_Members", "\u6240\u9700\u5143\u7D20" },
-            { "doclet.Annotation_Types_Summary", "\u6CE8\u91CA\u7C7B\u578B\u6982\u8981" },
             { "doclet.Author", "\u4F5C\u8005:" },
             { "doclet.Building_Index", "\u6B63\u5728\u6784\u5EFA\u6240\u6709\u7A0B\u5E8F\u5305\u548C\u7C7B\u7684\u7D22\u5F15..." },
             { "doclet.Building_Index_For_All_Classes", "\u6B63\u5728\u6784\u5EFA\u6240\u6709\u7C7B\u7684\u7D22\u5F15..." },
             { "doclet.Building_Tree", "\u6B63\u5728\u6784\u5EFA\u6240\u6709\u7A0B\u5E8F\u5305\u548C\u7C7B\u7684\u6811..." },
             { "doclet.Class", "\u7C7B" },
-            { "doclet.Class_0_extends_implements_serializable", "\u7C7B{0}\u6269\u5C55{1}\u5B9E\u73B0\u53EF\u5E8F\u5217\u5316" },
-            { "doclet.Class_0_implements_serializable", "\u7C7B{0}\u5B9E\u73B0\u53EF\u5E8F\u5217\u5316" },
-            { "doclet.Class_Summary", "\u7C7B\u6982\u8981" },
             { "doclet.Classes", "\u7C7B" },
             { "doclet.Concealed_Packages_Summary", "\u5DF2\u9690\u85CF" },
             { "doclet.Concrete_Methods", "\u5177\u4F53\u65B9\u6CD5" },
             { "doclet.ConstantField", "\u5E38\u91CF\u5B57\u6BB5" },
             { "doclet.Constants_Summary", "\u5E38\u91CF\u5B57\u6BB5\u503C" },
-            { "doclet.Constants_Table_Summary", "{0}\u8868, \u5217\u8868\u5E38\u91CF\u5B57\u6BB5\u548C\u503C" },
             { "doclet.Constructor", "\u6784\u9020\u5668" },
             { "doclet.Constructor_Detail", "\u6784\u9020\u5668\u8BE6\u7EC6\u8D44\u6599" },
             { "doclet.Constructor_Summary", "\u6784\u9020\u5668\u6982\u8981" },
             { "doclet.Constructors", "\u6784\u9020\u5668" },
+            { "doclet.Copied_snippet_to_clipboard", "\u5DF2\u590D\u5236\uFF01" },
+            { "doclet.Copy_Ignored_warning", "\u672A\u590D\u5236\u6587\u4EF6 {0}\uFF1A\u540D\u79F0\u65E0\u6548" },
             { "doclet.Copy_Overwrite_warning", "\u672A\u5C06\u6587\u4EF6{0}\u590D\u5236\u5230 {1}, \u56E0\u4E3A\u73B0\u6709\u6587\u4EF6\u5177\u6709\u76F8\u540C\u540D\u79F0..." },
+            { "doclet.Copy_snippet_to_clipboard", "\u590D\u5236" },
             { "doclet.Copying_File_0_To_Dir_1", "\u6B63\u5728\u5C06\u6587\u4EF6{0}\u590D\u5236\u5230\u76EE\u5F55 {1}..." },
             { "doclet.Copying_File_0_To_File_1", "\u6B63\u5728\u5C06\u6587\u4EF6{0}\u590D\u5236\u5230\u6587\u4EF6{1}..." },
             { "doclet.Default", "\u9ED8\u8BA4\u503C:" },
@@ -52,20 +52,17 @@ public final class doclets_zh_CN extends java.util.ListResourceBundle {
             { "doclet.Description", "\u8BF4\u660E" },
             { "doclet.Encoding_not_supported", "\u4E0D\u652F\u6301\u7F16\u7801: {0}" },
             { "doclet.Enum", "\u679A\u4E3E" },
+            { "doclet.EnumClass", "\u679A\u4E3E\u7C7B" },
+            { "doclet.EnumClasses", "\u679A\u4E3E\u7C7B" },
             { "doclet.Enum_Constant", "\u679A\u4E3E\u5E38\u91CF" },
             { "doclet.Enum_Constant_Detail", "\u679A\u4E3E\u5E38\u91CF\u8BE6\u7EC6\u8D44\u6599" },
             { "doclet.Enum_Constant_Summary", "\u679A\u4E3E\u5E38\u91CF\u6982\u8981" },
             { "doclet.Enum_Constants", "\u679A\u4E3E\u5E38\u91CF" },
-            { "doclet.Enum_Summary", "\u679A\u4E3E\u6982\u8981" },
             { "doclet.Enums", "\u679A\u4E3E" },
-            { "doclet.Error", "\u9519\u8BEF" },
-            { "doclet.Error_Summary", "\u9519\u8BEF\u6982\u8981" },
             { "doclet.Error_invalid_custom_tag_argument", "\u9519\u8BEF - \u5BF9\u4E8E -tag \u9009\u9879, {0}\u662F\u65E0\u6548\u53C2\u6570..." },
             { "doclet.Error_taglet_not_registered", "\u9519\u8BEF - \u5C1D\u8BD5\u6CE8\u518C Taglet {1}\u65F6\u629B\u51FA\u5F02\u5E38\u9519\u8BEF{0}..." },
-            { "doclet.Errors", "\u9519\u8BEF" },
-            { "doclet.Exception", "\u5F02\u5E38\u9519\u8BEF" },
-            { "doclet.Exception_Summary", "\u5F02\u5E38\u9519\u8BEF\u6982\u8981" },
-            { "doclet.Exceptions", "\u5F02\u5E38\u9519\u8BEF" },
+            { "doclet.ExceptionClass", "\u5F02\u5E38\u9519\u8BEF\u7C7B" },
+            { "doclet.ExceptionClasses", "\u5F02\u5E38\u9519\u8BEF\u7C7B" },
             { "doclet.ExportedTo", "\u5DF2\u5BFC\u51FA\u5230\u6A21\u5757" },
             { "doclet.Exported_Packages_Summary", "\u5BFC\u51FA\u9879" },
             { "doclet.Factory", "\u5DE5\u5382:" },
@@ -84,15 +81,12 @@ public final class doclets_zh_CN extends java.util.ListResourceBundle {
             { "doclet.Implementation", "\u5B9E\u73B0:" },
             { "doclet.Indirect_Exports_Summary", "\u95F4\u63A5\u5BFC\u51FA\u9879" },
             { "doclet.Indirect_Opens_Summary", "\u95F4\u63A5\u6253\u5F00\u9879" },
-            { "doclet.Indirect_Packages_Table_Summary", "{0} \u8868, \u5176\u4E2D\u5217\u51FA {1} \u548C {2}" },
             { "doclet.Indirect_Requires_Summary", "\u95F4\u63A5\u5FC5\u9700\u9879" },
             { "doclet.Instance_Methods", "\u5B9E\u4F8B\u65B9\u6CD5" },
             { "doclet.Interface", "\u63A5\u53E3" },
-            { "doclet.Interface_Summary", "\u63A5\u53E3\u6982\u8981" },
             { "doclet.Interfaces", "\u63A5\u53E3" },
             { "doclet.JavaScript_in_comment", "\u6587\u6863\u6CE8\u91CA\u4E2D\u53D1\u73B0 JavaScript\u3002\n\u4F7F\u7528 --allow-script-in-comments \u53EF\u5141\u8BB8\u4F7F\u7528 JavaScript\u3002" },
             { "doclet.JavaScript_in_option", "\u9009\u9879 {0} \u5305\u542B JavaScript\u3002\n\u4F7F\u7528 --allow-script-in-comments \u53EF\u5141\u8BB8\u4F7F\u7528 JavaScript\u3002" },
-            { "doclet.Member_Table_Summary", "{0}\u8868, \u5217\u8868{1}\u548C\u89E3\u91CA" },
             { "doclet.Method", "\u65B9\u6CD5" },
             { "doclet.Method_Detail", "\u65B9\u6CD5\u8BE6\u7EC6\u8D44\u6599" },
             { "doclet.Method_Summary", "\u65B9\u6CD5\u6982\u8981" },
@@ -105,7 +99,6 @@ public final class doclets_zh_CN extends java.util.ListResourceBundle {
             { "doclet.MissingSerialTag", "\u5728\u7C7B{0}\u4E2D, \u9ED8\u8BA4\u7684\u53EF\u5E8F\u5217\u5316\u5B57\u6BB5{1}\u7F3A\u5C11 @serial \u6807\u8BB0\u3002" },
             { "doclet.Modifier", "\u9650\u5B9A\u7B26" },
             { "doclet.Modifier_and_Type", "\u4FEE\u9970\u7B26\u548C\u7C7B\u578B" },
-            { "doclet.Module_Summary", "\u6A21\u5757\u6982\u8981" },
             { "doclet.Modules", "\u6A21\u5757" },
             { "doclet.Nested_Class_Summary", "\u5D4C\u5957\u7C7B\u6982\u8981" },
             { "doclet.Nested_Classes", "\u5D4C\u5957\u7C7B" },
@@ -115,7 +108,7 @@ public final class doclets_zh_CN extends java.util.ListResourceBundle {
             { "doclet.Nested_Classes_Interfaces_Inherited_From_Interface", "\u4ECE\u63A5\u53E3\u7EE7\u627F\u7684\u5D4C\u5957\u7C7B/\u63A5\u53E3" },
             { "doclet.No_Public_Classes_To_Document", "\u627E\u4E0D\u5230\u53EF\u4EE5\u6587\u6863\u5316\u7684\u516C\u5171\u6216\u53D7\u4FDD\u62A4\u7684\u7C7B\u3002" },
             { "doclet.Notice_taglet_conflict_warn", "\u6CE8: \u53EF\u80FD\u8986\u76D6\u5C06\u6765\u7684\u6807\u51C6\u6807\u8BB0\u7684\u5B9A\u5236\u6807\u8BB0: {0}\u3002\u4E3A\u4E86\u907F\u514D\u51FA\u73B0\u53EF\u80FD\u7684\u8986\u76D6, \u8BF7\u5728\u5B9A\u5236\u6807\u8BB0\u540D\u79F0\u4E2D\u81F3\u5C11\u4F7F\u7528\u4E00\u4E2A\u53E5\u70B9\u5B57\u7B26 (.)\u3002" },
-            { "doclet.Notice_taglet_overriden", "\u6CE8: \u8986\u76D6\u6807\u51C6\u6807\u8BB0\u7684\u5B9A\u5236\u6807\u8BB0: {0}" },
+            { "doclet.Notice_taglet_overridden", "\u6CE8: \u8986\u76D6\u6807\u51C6\u6807\u8BB0\u7684\u5B9A\u5236\u6807\u8BB0: {0}" },
             { "doclet.Notice_taglet_registered", "\u6CE8\u518C\u7684 Taglet {0}..." },
             { "doclet.Notice_taglet_unseen", "\u6CE8: \u627E\u4E0D\u5230\u7684\u5B9A\u5236\u6807\u8BB0: {0}" },
             { "doclet.OpenedTo", "\u5DF2\u6253\u5F00\u5230\u6A21\u5757" },
@@ -129,13 +122,12 @@ public final class doclets_zh_CN extends java.util.ListResourceBundle {
             { "doclet.Other_Modules", "\u5176\u4ED6\u6A21\u5757" },
             { "doclet.Other_Packages", "\u5176\u4ED6\u7A0B\u5E8F\u5305" },
             { "doclet.Package_Summary", "\u7A0B\u5E8F\u5305\u6982\u8981" },
-            { "doclet.Package_class_and_interface_descriptions", "\u7A0B\u5E8F\u5305, \u7C7B\u548C\u63A5\u53E3\u8BF4\u660E" },
             { "doclet.Package_private", "(\u4E13\u7528\u7A0B\u5E8F\u5305)" },
             { "doclet.Packages", "\u7A0B\u5E8F\u5305" },
-            { "doclet.Packages_Summary", "\u7A0B\u5E8F\u5305" },
             { "doclet.Parameters", "\u53C2\u6570:" },
             { "doclet.Parameters_dup_warn", "\u591A\u6B21\u5BF9\u53C2\u6570 \"{0}\" \u8FDB\u884C\u6587\u6863\u5316\u3002" },
             { "doclet.Parameters_warn", "@param argument \"{0}\" \u4E0D\u662F\u53C2\u6570\u540D\u79F0\u3002" },
+            { "doclet.Preview", "\u9884\u89C8\u3002" },
             { "doclet.Properties", "\u5C5E\u6027" },
             { "doclet.Properties_Declared_In_Class", "\u5728\u7C7B\u4E2D\u58F0\u660E\u7684\u5C5E\u6027" },
             { "doclet.Properties_Declared_In_Interface", "\u5728\u63A5\u53E3\u4E2D\u58F0\u660E\u7684\u5C5E\u6027" },
@@ -143,17 +135,24 @@ public final class doclets_zh_CN extends java.util.ListResourceBundle {
             { "doclet.Properties_Inherited_From_Interface", "\u4ECE\u63A5\u53E3\u7EE7\u627F\u7684\u5C5E\u6027" },
             { "doclet.Property", "\u5C5E\u6027" },
             { "doclet.PropertyDescription", "\u5C5E\u6027\u8BF4\u660E:" },
-            { "doclet.PropertyGetter", "\u83B7\u53D6\u5C5E\u6027\u7684\u503C" },
-            { "doclet.PropertyGetterWithName", "\u83B7\u53D6\u5C5E\u6027{0}\u7684\u503C\u3002" },
-            { "doclet.PropertySetter", "\u8BBE\u7F6E\u5C5E\u6027\u7684\u503C" },
-            { "doclet.PropertySetterWithName", "\u8BBE\u7F6E\u5C5E\u6027{0}\u7684\u503C\u3002" },
-            { "doclet.Property_Detail", "\u5C5E\u6027\u8BE6\u7EC6\u4FE1\u606F" },
+            { "doclet.PropertyGetterReturn", "{0} \u5C5E\u6027\u7684\u503C" },
+            { "doclet.PropertyGetterWithName", "\u83B7\u53D6{0}\u5C5E\u6027\u7684\u503C\u3002" },
+            { "doclet.PropertyMethodReturn", "{0} \u5C5E\u6027" },
+            { "doclet.PropertySetterParam", "{0} \u5C5E\u6027\u7684\u503C" },
+            { "doclet.PropertySetterWithName", "\u8BBE\u7F6E{0}\u5C5E\u6027\u7684\u503C\u3002" },
+            { "doclet.Property_Detail", "\u5C5E\u6027\u8BE6\u7EC6\u8D44\u6599" },
             { "doclet.Property_Summary", "\u5C5E\u6027\u6982\u8981" },
             { "doclet.Provides_Summary", "\u63D0\u4F9B" },
+            { "doclet.RecordClass", "\u8BB0\u5F55\u7C7B" },
+            { "doclet.RecordClasses", "\u8BB0\u5F55\u7C7B" },
+            { "doclet.RecordComponents", "\u8BB0\u5F55\u7EC4\u4EF6\uFF1A" },
+            { "doclet.RecordComponents_dup_warn", "\u591A\u6B21\u5BF9\u8BB0\u5F55\u7EC4\u4EF6 \"{0}\" \u8FDB\u884C\u6587\u6863\u5316\u3002" },
+            { "doclet.RecordComponents_warn", "@param argument \"{0}\" \u4E0D\u662F\u8BB0\u5F55\u7EC4\u4EF6\u540D\u79F0\u3002" },
+            { "doclet.Related_Packages", "\u76F8\u5173\u7A0B\u5E8F\u5305" },
             { "doclet.Requires_Summary", "\u5FC5\u9700\u9879" },
             { "doclet.Return_tag_on_void_method", "\u4E0D\u80FD\u5728\u8FD4\u56DE\u7C7B\u578B\u4E3A\u7A7A\u7684\u65B9\u6CD5\u4E2D\u4F7F\u7528 @return \u6807\u8BB0\u3002" },
             { "doclet.Returns", "\u8FD4\u56DE:" },
-            { "doclet.See", "\u8BF7\u53C2\u9605:" },
+            { "doclet.Returns_0", "\u8FD4\u56DE {0}\u3002" },
             { "doclet.See_Also", "\u53E6\u8BF7\u53C2\u9605:" },
             { "doclet.SerialData", "\u5E8F\u5217\u6570\u636E:" },
             { "doclet.Serializable_no_customization", "\u672A\u58F0\u660E readObject \u6216 writeObject \u65B9\u6CD5\u3002" },
@@ -168,62 +167,104 @@ public final class doclets_zh_CN extends java.util.ListResourceBundle {
             { "doclet.Toolkit_Usage_Violation", "\u53EA\u6709{0}\u53EF\u4EE5\u4F7F\u7528 Doclet \u5DE5\u5177\u7BB1" },
             { "doclet.Type", "\u7C7B\u578B" },
             { "doclet.TypeParameters", "\u7C7B\u578B\u53C2\u6570:" },
-            { "doclet.Type_Parameters_dup_warn", "\u591A\u6B21\u5BF9\u7C7B\u578B\u53C2\u6570 \"{0}\" \u8FDB\u884C\u6587\u6863\u5316\u3002" },
-            { "doclet.Type_Parameters_warn", "@param argument \"{0}\" \u4E0D\u662F\u7C7B\u578B\u53C2\u6570\u540D\u79F0\u3002" },
+            { "doclet.TypeParameters_dup_warn", "\u591A\u6B21\u5BF9\u7C7B\u578B\u53C2\u6570 \"{0}\" \u8FDB\u884C\u6587\u6863\u5316\u3002" },
+            { "doclet.TypeParameters_warn", "@param argument \"{0}\" \u4E0D\u662F\u7C7B\u578B\u53C2\u6570\u540D\u79F0\u3002" },
             { "doclet.UnknownTag", "{0}\u662F\u672A\u77E5\u6807\u8BB0\u3002" },
             { "doclet.UnknownTagLowercase", "{0}\u662F\u672A\u77E5\u6807\u8BB0 - \u9664\u4E86\u5927\u5C0F\u5199\u4E4B\u5916\u5176\u4ED6\u65B9\u9762\u4E0E\u5DF2\u77E5\u6807\u8BB0\u76F8\u540C\u3002" },
-            { "doclet.Use_Table_Summary", "\u4F7F\u7528\u8868, \u5217\u8868{0}\u548C\u89E3\u91CA" },
             { "doclet.Uses_Summary", "\u4F7F\u7528" },
             { "doclet.Value", "\u503C" },
             { "doclet.Version", "\u7248\u672C:" },
-            { "doclet.annotation_type_optional_members", "\u53EF\u9009\u5143\u7D20" },
-            { "doclet.annotation_type_required_members", "\u5FC5\u9700\u7684\u5143\u7D20" },
+            { "doclet.annotationinterface", "\u6CE8\u91CA\u63A5\u53E3" },
+            { "doclet.annotationinterfaces", "\u6CE8\u91CA\u63A5\u53E3" },
             { "doclet.annotationtype", "\u6CE8\u91CA\u7C7B\u578B" },
             { "doclet.annotationtypes", "\u6CE8\u91CA\u7C7B\u578B" },
+            { "doclet.cannot_use_snippet_path", "\u4E0D\u80FD\u5C06 ''--snippet-path'' \u9009\u9879\u4E0E\u7ED9\u5B9A\u7684\u6587\u4EF6\u7BA1\u7406\u5668 {0} \u4E00\u8D77\u4F7F\u7528" },
             { "doclet.class", "\u7C7B" },
-            { "doclet.classes", "\u7C7B" },
-            { "doclet.constructors", "\u6784\u9020\u5668" },
             { "doclet.dest_dir_create", "\u6B63\u5728\u521B\u5EFA\u76EE\u6807\u76EE\u5F55: \"{0}\"" },
             { "doclet.destination_directory_not_directory_0", "\u76EE\u6807\u76EE\u5F55\u4E0D\u662F\u76EE\u5F55: {0}" },
             { "doclet.destination_directory_not_writable_0", "\u76EE\u6807\u76EE\u5F55\u4E0D\u53EF\u5199: {0}" },
+            { "doclet.duplicate.comment.for.property", "\u5C5E\u6027\u6CE8\u91CA\u91CD\u590D\u3002\n\u5220\u9664\u5C5E\u6027\u5B57\u6BB5\u6216\u6B64\u65B9\u6CD5\u7684\u6CE8\u91CA\u4EE5\u9690\u85CF\u6B64\u8B66\u544A\u3002" },
             { "doclet.enum", "\u679A\u4E3E" },
-            { "doclet.enum_constants", "\u679A\u4E3E\u5E38\u91CF" },
+            { "doclet.enum_class_valueof_doc.fullbody", "\u8FD4\u56DE\u5E26\u6709\u6307\u5B9A\u540D\u79F0\u7684\u8BE5\u7C7B\u7684\u679A\u4E3E\u5E38\u91CF\u3002\n\u5B57\u7B26\u4E32\u5FC5\u987B\u4E0E\u7528\u4E8E\u58F0\u660E\u8BE5\u7C7B\u7684\u679A\u4E3E\u5E38\u91CF\u7684\n\u6807\u8BC6\u7B26<i>\u5B8C\u5168</i>\u5339\u914D\u3002\uFF08\u4E0D\u5141\u8BB8\u6709\u591A\u4F59\n\u7684\u7A7A\u683C\u5B57\u7B26\u3002\uFF09" },
+            { "doclet.enum_class_valueof_doc.throws_ila", "\u5982\u679C\u8BE5\u679A\u4E3E\u7C7B\u6CA1\u6709\u5E26\u6709\u6307\u5B9A\u540D\u79F0\u7684\u5E38\u91CF" },
+            { "doclet.enum_class_values_doc.fullbody", "\u8FD4\u56DE\u5305\u542B\u8BE5\u679A\u4E3E\u7C7B\u7684\u5E38\u91CF\u7684\u6570\u7EC4\uFF0C\n\u987A\u5E8F\u4E0E\u58F0\u660E\u8FD9\u4E9B\u5E38\u91CF\u7684\u987A\u5E8F\u76F8\u540C" },
+            { "doclet.enum_class_values_doc.return", "\u5305\u542B\u8BE5\u679A\u4E3E\u7C7B\u7684\u5E38\u91CF\u7684\u6570\u7EC4\uFF0C\u987A\u5E8F\u4E0E\u58F0\u660E\u8FD9\u4E9B\u5E38\u91CF\u7684\u987A\u5E8F\u76F8\u540C" },
             { "doclet.enum_valueof_doc.fullbody", "\u8FD4\u56DE\u5E26\u6709\u6307\u5B9A\u540D\u79F0\u7684\u8BE5\u7C7B\u578B\u7684\u679A\u4E3E\u5E38\u91CF\u3002\n\u5B57\u7B26\u4E32\u5FC5\u987B\u4E0E\u7528\u4E8E\u58F0\u660E\u8BE5\u7C7B\u578B\u7684\u679A\u4E3E\u5E38\u91CF\u7684\n\u6807\u8BC6\u7B26<i>\u5B8C\u5168</i>\u5339\u914D\u3002(\u4E0D\u5141\u8BB8\u6709\u591A\u4F59\n\u7684\u7A7A\u683C\u5B57\u7B26\u3002)" },
             { "doclet.enum_valueof_doc.param_name", "\u8981\u8FD4\u56DE\u7684\u679A\u4E3E\u5E38\u91CF\u7684\u540D\u79F0\u3002" },
             { "doclet.enum_valueof_doc.return", "\u8FD4\u56DE\u5E26\u6709\u6307\u5B9A\u540D\u79F0\u7684\u679A\u4E3E\u5E38\u91CF" },
             { "doclet.enum_valueof_doc.throws_ila", "\u5982\u679C\u8BE5\u679A\u4E3E\u7C7B\u578B\u6CA1\u6709\u5E26\u6709\u6307\u5B9A\u540D\u79F0\u7684\u5E38\u91CF" },
             { "doclet.enum_valueof_doc.throws_npe", "\u5982\u679C\u53C2\u6570\u4E3A\u7A7A\u503C" },
-            { "doclet.enum_values_doc.fullbody", "\u6309\u7167\u58F0\u660E\u8BE5\u679A\u4E3E\u7C7B\u578B\u7684\u5E38\u91CF\u7684\u987A\u5E8F, \n\u8FD4\u56DE\u4E00\u4E2A\u5305\u542B\u8FD9\u4E9B\u5E38\u91CF\u7684\u6570\u7EC4\u3002" },
-            { "doclet.enum_values_doc.return", "\u6309\u7167\u58F0\u660E\u8BE5\u679A\u4E3E\u7C7B\u578B\u7684\u5E38\u91CF\u7684\u987A\u5E8F\u8FD4\u56DE\u7684\u5305\u542B\u8FD9\u4E9B\u5E38\u91CF\u7684\u6570\u7EC4" },
+            { "doclet.enum_values_doc.fullbody", "\u8FD4\u56DE\u5305\u542B\u8BE5\u679A\u4E3E\u7C7B\u578B\u7684\u5E38\u91CF\u7684\u6570\u7EC4\uFF0C\n\u987A\u5E8F\u4E0E\u58F0\u660E\u8FD9\u4E9B\u5E38\u91CF\u7684\u987A\u5E8F\u76F8\u540C" },
+            { "doclet.enum_values_doc.return", "\u5305\u542B\u8BE5\u679A\u4E3E\u7C7B\u578B\u7684\u5E38\u91CF\u7684\u6570\u7EC4\uFF0C\u987A\u5E8F\u4E0E\u58F0\u660E\u8FD9\u4E9B\u5E38\u91CF\u7684\u987A\u5E8F\u76F8\u540C" },
+            { "doclet.enumclass", "\u679A\u4E3E\u7C7B" },
+            { "doclet.enumclasses", "\u679A\u4E3E\u7C7B" },
             { "doclet.enums", "\u679A\u4E3E" },
-            { "doclet.error", "\u9519\u8BEF" },
             { "doclet.error.initializing.dest.dir", "\u521D\u59CB\u5316\u76EE\u6807\u76EE\u5F55\u65F6\u51FA\u9519: {0}" },
-            { "doclet.errors", "\u9519\u8BEF" },
-            { "doclet.exception", "\u5F02\u5E38\u9519\u8BEF" },
+            { "doclet.error_setting_snippet_path", "\u8BBE\u7F6E\u7247\u6BB5\u8DEF\u5F84 {0} \u65F6\u51FA\u9519\uFF1A{1}" },
             { "doclet.exception.read.file", "\u8BFB\u53D6\u6587\u4EF6\u65F6\u51FA\u9519: {0}\n\t({1})" },
             { "doclet.exception.read.resource", "\u8BFB\u53D6\u7CFB\u7EDF\u8D44\u6E90\u65F6\u51FA\u9519: {0}\n\t({1})" },
             { "doclet.exception.write.file", "\u5199\u5165\u6587\u4EF6\u65F6\u51FA\u9519: {0}\n\t({1})" },
-            { "doclet.exceptions", "\u5F02\u5E38\u9519\u8BEF" },
-            { "doclet.fields", "\u5B57\u6BB5" },
+            { "doclet.exceptionclass", "\u5F02\u5E38\u9519\u8BEF\u7C7B" },
             { "doclet.in", "{1}\u4E2D\u7684{0}" },
             { "doclet.interface", "\u63A5\u53E3" },
-            { "doclet.interfaces", "\u63A5\u53E3" },
             { "doclet.internal.exception", "\u51FA\u73B0\u5185\u90E8\u5F02\u5E38\u9519\u8BEF\u3002\n\t({0})" },
             { "doclet.internal.report.bug", "\u5982\u679C\u5728 Bug Database (http://bugs.java.com) \u4E2D\u6CA1\u6709\u627E\u5230\u91CD\u590D\u9879, \n\u8BF7\u901A\u8FC7 Java Bug \u62A5\u544A\u9875 (http://bugreport.java.com) \u9488\u5BF9\u8BE5 \njavadoc \u5DE5\u5177\u5EFA\u7ACB Bug\u3002\u8BF7\u5728\u62A5\u544A\u4E2D\u9644\u4E0A\u9519\u8BEF\u6D88\u606F\u548C\u4EE5\u4E0B\u8BCA\u65AD\u4FE1\u606F\u3002\u8C22\u8C22\u3002" },
             { "doclet.linkMismatch_ModuleLinkedtoPackage", "\u8FDB\u884C\u6587\u6863\u5316\u7684\u4EE3\u7801\u4F7F\u7528\u4E86\u6A21\u5757\uFF0C\u4F46\u5728 {0} \u4E2D\u5B9A\u4E49\u7684\u7A0B\u5E8F\u5305\u5728\u672A\u547D\u540D\u6A21\u5757\u4E2D\u3002" },
             { "doclet.linkMismatch_PackagedLinkedtoModule", "\u8FDB\u884C\u6587\u6863\u5316\u7684\u4EE3\u7801\u4F7F\u7528\u4E86\u672A\u547D\u540D\u6A21\u5757\u4E2D\u7684\u7A0B\u5E8F\u5305\uFF0C\u4F46\u5728 {0} \u4E2D\u5B9A\u4E49\u7684\u7A0B\u5E8F\u5305\u5728\u547D\u540D\u6A21\u5757\u4E2D\u3002" },
-            { "doclet.methods", "\u65B9\u6CD5" },
-            { "doclet.modules", "\u6A21\u5757" },
-            { "doclet.nested_classes", "\u5D4C\u5957\u7C7B" },
             { "doclet.noInheritedDoc", "\u4F7F\u7528\u4E86 @inheritDoc, \u4F46{0}\u672A\u8986\u76D6\u6216\u5B9E\u73B0\u4EFB\u4F55\u65B9\u6CD5\u3002" },
-            { "doclet.packages", "\u7A0B\u5E8F\u5305" },
-            { "doclet.properties", "\u5C5E\u6027" },
+            { "doclet.not_standard_file_manager", "\u65E0\u6CD5\u8BBE\u7F6E taglet \u8DEF\u5F84\uFF1B\u6587\u4EF6\u7BA1\u7406\u5668\u4E0D\u662F StandardJavaFileManager" },
+            { "doclet.platform.docs.ea", "https://download.java.net/java/early_access/jdk{0}/docs/api/" },
+            { "doclet.platform.docs.new", "https://docs.oracle.com/en/java/javase/{0}/docs/api/" },
+            { "doclet.platform.docs.old", "https://docs.oracle.com/javase/{0}/docs/api/" },
+            { "doclet.record_accessor_doc.fullbody", "\u8FD4\u56DE {0} \u8BB0\u5F55\u7EC4\u4EF6\u7684\u503C\u3002" },
+            { "doclet.record_accessor_doc.return", "{0} \u8BB0\u5F55\u7EC4\u4EF6\u7684\u503C" },
+            { "doclet.record_constructor_doc.fullbody", "\u521B\u5EFA {0} \u8BB0\u5F55\u7C7B\u7684\u5B9E\u4F8B\u3002" },
+            { "doclet.record_constructor_doc.param_name", "{0} \u8BB0\u5F55\u7EC4\u4EF6\u7684\u503C" },
+            { "doclet.record_equals_doc.fullbody.head", "\u6307\u793A\u67D0\u4E2A\u5176\u4ED6\u5BF9\u8C61\u662F\u5426\u201C\u7B49\u4E8E\u201D\u6B64\u5BF9\u8C61\u3002\u5982\u679C\u4E24\u4E2A\u5BF9\u8C61\u5C5E\u4E8E\u540C\u4E00\u4E2A\u7C7B\uFF0C\u800C\u4E14\u6240\u6709\u8BB0\u5F55\u7EC4\u4EF6\u90FD\u76F8\u7B49\uFF0C\u5219\u8FD9\u4E24\u4E2A\u5BF9\u8C61\u76F8\u7B49\u3002" },
+            { "doclet.record_equals_doc.fullbody.tail.both", "\u4F7F\u7528 {@link java.util.Objects#equals(Object,Object) Objects::equals(Object,Object)} \u5BF9\u53C2\u8003\u7EC4\u4EF6\u8FDB\u884C\u6BD4\u8F83\uFF1B\u4F7F\u7528 '==' \u5BF9\u57FA\u5143\u7EC4\u4EF6\u8FDB\u884C\u6BD4\u8F83" },
+            { "doclet.record_equals_doc.fullbody.tail.primitive", "\u6B64\u8BB0\u5F55\u7C7B\u4E2D\u7684\u6240\u6709\u7EC4\u4EF6\u90FD\u4F7F\u7528 '==' \u8FDB\u884C\u6BD4\u8F83\u3002" },
+            { "doclet.record_equals_doc.fullbody.tail.reference", "\u6B64\u8BB0\u5F55\u7C7B\u4E2D\u7684\u6240\u6709\u7EC4\u4EF6\u90FD\u4F7F\u7528 {@link java.util.Objects#equals(Object,Object) Objects::equals(Object,Object)} \u8FDB\u884C\u6BD4\u8F83\u3002" },
+            { "doclet.record_equals_doc.param_name", "\u8981\u4E0E\u4E4B\u8FDB\u884C\u6BD4\u8F83\u7684\u5BF9\u8C61" },
+            { "doclet.record_equals_doc.return", "\u5982\u679C\u6B64\u5BF9\u8C61\u4E0E {0} \u53C2\u6570\u76F8\u540C\uFF0C\u5219\u4E3A <code>true</code>\uFF1B\u5426\u5219\u4E3A <code>false</code>\u3002" },
+            { "doclet.record_field_doc.fullbody", "{0} \u8BB0\u5F55\u7EC4\u4EF6\u7684\u5B57\u6BB5\u3002" },
+            { "doclet.record_hashCode_doc.fullbody", "\u8FD4\u56DE\u6B64\u5BF9\u8C61\u7684\u54C8\u5E0C\u4EE3\u7801\u503C\u3002\u6B64\u503C\u6D3E\u751F\u81EA\u6BCF\u4E2A\u8BB0\u5F55\u7EC4\u4EF6\u7684\u54C8\u5E0C\u4EE3\u7801\u3002" },
+            { "doclet.record_hashCode_doc.return", "\u6B64\u5BF9\u8C61\u7684\u54C8\u5E0C\u4EE3\u7801\u503C" },
+            { "doclet.record_toString_doc.fullbody", "\u8FD4\u56DE\u6B64\u8BB0\u5F55\u7C7B\u7684\u5B57\u7B26\u4E32\u8868\u793A\u5F62\u5F0F\u3002\u6B64\u8868\u793A\u5F62\u5F0F\u5305\u542B\u7C7B\u7684\u540D\u79F0\uFF0C\u540E\u8DDF\u6BCF\u4E2A\u8BB0\u5F55\u7EC4\u4EF6\u7684\u540D\u79F0\u548C\u503C\u3002" },
+            { "doclet.record_toString_doc.return", "\u6B64\u5BF9\u8C61\u7684\u5B57\u7B26\u4E32\u8868\u793A\u5F62\u5F0F" },
+            { "doclet.recordclass", "\u8BB0\u5F55\u7C7B" },
             { "doclet.search", "SEARCH:" },
+            { "doclet.search.classes_and_interfaces", "\u7C7B\u548C\u63A5\u53E3" },
+            { "doclet.search.loading", "\u6B63\u5728\u52A0\u8F7D\u641C\u7D22\u7D22\u5F15..." },
+            { "doclet.search.members", "\u6210\u5458" },
+            { "doclet.search.modules", "\u6A21\u5757" },
+            { "doclet.search.no_results", "\u672A\u627E\u5230\u7ED3\u679C" },
+            { "doclet.search.packages", "\u7A0B\u5E8F\u5305" },
+            { "doclet.search.search_tags", "\u641C\u7D22\u6807\u8BB0" },
+            { "doclet.search.types", "\u7C7B\u578B" },
+            { "doclet.search_placeholder", "\u641C\u7D22" },
+            { "doclet.snippet.contents.ambiguity.external", "@snippet \u6307\u5B9A\u4E86\u591A\u4E2A\u5916\u90E8\u5185\u5BB9\uFF0C\u8FD9\u4F1A\u5F15\u8D77\u6DF7\u6DC6" },
+            { "doclet.snippet.contents.mismatch", "\u5185\u5BB9\u4E0D\u5339\u914D\uFF1A\n{0}" },
+            { "doclet.snippet.contents.none", "@snippet \u672A\u6307\u5B9A\u5185\u5BB9" },
+            { "doclet.snippet.markup", "\u7247\u6BB5\u6807\u8BB0\uFF1A{0}" },
+            { "doclet.snippet.markup.attribute.absent", "\u7F3A\u5C11\u5C5E\u6027 \"{0}\"" },
+            { "doclet.snippet.markup.attribute.simultaneous.use", "\u540C\u65F6\u4F7F\u7528\u4E86\u5C5E\u6027 \"{0}\" \u548C \"{1}\"" },
+            { "doclet.snippet.markup.attribute.unexpected", "\u610F\u5916\u7684\u5C5E\u6027" },
+            { "doclet.snippet.markup.attribute.value.invalid", "\u5C5E\u6027\u503C\u65E0\u6548" },
+            { "doclet.snippet.markup.attribute.value.unterminated", "\u672A\u7EC8\u6B62\u7684\u5C5E\u6027\u503C" },
+            { "doclet.snippet.markup.regex.invalid", "\u6B63\u5219\u8868\u8FBE\u5F0F\u65E0\u6548" },
+            { "doclet.snippet.markup.region.duplicated", "\u91CD\u590D\u7684\u533A\u57DF" },
+            { "doclet.snippet.markup.region.none", "\u6CA1\u6709\u7ED3\u675F\u533A\u57DF" },
+            { "doclet.snippet.markup.region.unpaired", "\u533A\u57DF\u4E0D\u914D\u5BF9" },
+            { "doclet.snippet.markup.spurious", "\u865A\u5047\u6807\u8BB0" },
+            { "doclet.snippet.markup.tag.non.existent.lines", "\u6807\u8BB0\u5F15\u7528\u4E0D\u5B58\u5728\u7684\u884C" },
+            { "doclet.snippet.region.not_found", "\u627E\u4E0D\u5230\u533A\u57DF\uFF1A\"{0}\"" },
+            { "doclet.snippet_file_not_found", "\u5728\u6E90\u8DEF\u5F84\u6216\u7247\u6BB5\u8DEF\u5F84\u4E2D\u627E\u4E0D\u5230\u6587\u4EF6\uFF1A{0}" },
             { "doclet.sourcetab_warning", "-sourcetab \u7684\u53C2\u6570\u5FC5\u987B\u662F\u5927\u4E8E 0 \u7684\u6574\u6570\u3002" },
-            { "doclet.subclasses", "\u5B50\u7C7B" },
-            { "doclet.subinterfaces", "\u5B50\u63A5\u53E3" },
+            { "doclet.tag.attribute.repeated", "\u91CD\u590D\u5C5E\u6027\uFF1A\"{0}\"" },
+            { "doclet.tag.attribute.value.illegal", "\u5C5E\u6027 \"{0}\" \u7684\u503C\u975E\u6CD5\uFF1A\"{1}\"" },
+            { "doclet.tag.attribute.value.missing", "\u5C5E\u6027 \"{0}\" \u7F3A\u5C11\u503C" },
             { "doclet.tag_misuse", "\u4E0D\u80FD\u5728{1}\u6587\u6863\u4E2D\u4F7F\u7528\u6807\u8BB0{0}\u3002\u53EA\u80FD\u5728\u4EE5\u4E0B\u7C7B\u578B\u7684\u6587\u6863\u4E2D\u4F7F\u7528\u8BE5\u6807\u8BB0: {2}\u3002" },
-            { "doclet.types", "\u7C7B\u578B" },
+            { "doclet.taglet_could_not_set_location", "\u65E0\u6CD5\u8BBE\u7F6E taglet \u8DEF\u5F84\uFF1A{0}" },
             { "doclet.urlRedirected", "URL {0} \u5DF2\u91CD\u5B9A\u5411\u5230 {1} \u2014 \u66F4\u65B0\u547D\u4EE4\u884C\u9009\u9879\u4EE5\u9690\u85CF\u6B64\u8B66\u544A\u3002" },
             { "doclet.value_tag_invalid_constant", "@value \u6807\u8BB0 (\u5F15\u7528{0}) \u53EA\u80FD\u5728\u5E38\u91CF\u4E2D\u4F7F\u7528\u3002" },
             { "doclet.value_tag_invalid_reference", "{0} (\u7531 @value \u6807\u8BB0\u5F15\u7528) \u4E3A\u672A\u77E5\u5F15\u7528\u3002" },
