@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -71,49 +67,40 @@ public class FormatData_es_UY extends ListResourceBundle {
     @Override
     protected final Object[][] getContents() {
         final String[] metaValue_MonthNames = new String[] {
-               "enero",
-               "febrero",
-               "marzo",
-               "abril",
-               "mayo",
-               "junio",
-               "julio",
-               "agosto",
-               "setiembre",
-               "octubre",
-               "noviembre",
-               "diciembre",
-               "",
-            };
+            "enero",
+            "febrero",
+            "marzo",
+            "abril",
+            "mayo",
+            "junio",
+            "julio",
+            "agosto",
+            "setiembre",
+            "octubre",
+            "noviembre",
+            "diciembre",
+            "",
+        };
         final String[] metaValue_MonthAbbreviations = new String[] {
-               "ene.",
-               "feb.",
-               "mar.",
-               "abr.",
-               "may.",
-               "jun.",
-               "jul.",
-               "ago.",
-               "set.",
-               "oct.",
-               "nov.",
-               "dic.",
-               "",
-            };
-        final String[] metaValue_AmPmMarkers = new String[] {
-               "a. m.",
-               "p. m.",
-            };
+            "ene.",
+            "feb.",
+            "mar.",
+            "abr.",
+            "may.",
+            "jun.",
+            "jul.",
+            "ago.",
+            "set.",
+            "oct.",
+            "nov.",
+            "dic.",
+            "",
+        };
         final Object[][] data = new Object[][] {
-            { "MonthNames", metaValue_MonthNames },
-            { "japanese.MonthNames", metaValue_MonthNames },
-            { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
-            { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
-            { "AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
+            { "MonthNames", metaValue_MonthNames },
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "japanese.MonthNames", metaValue_MonthNames },
             { "latn.NumberElements",
                 new String[] {
                     ",",
@@ -127,12 +114,13 @@ public class FormatData_es_UY extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "roc.MonthNames", metaValue_MonthNames },
-            { "abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "standalone.MonthNames",
                 new String[] {
                     "Enero",
@@ -167,18 +155,15 @@ public class FormatData_es_UY extends ListResourceBundle {
                     "",
                 }
             },
-            { "japanese.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
-            { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
-            { "NumberPatterns",
+            { "latn.NumberPatterns",
                 new String[] {
                     "#,##0.###",
                     "\u00a4\u00a0#,##0.00",
                     "#,##0\u00a0%",
+                    "\u00a4\u00a0#,##0.00;(\u00a4\u00a0#,##0.00)",
                 }
             },
-            { "buddhist.narrow.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
-            { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
+            { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
         };
         return data;
     }
