@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -66,18 +66,19 @@ import java.util.ListResourceBundle;
 public class FormatData_fr_TD extends ListResourceBundle {
     @Override
     protected final Object[][] getContents() {
-        final String[] metaValue_TimePatterns = new String[] {
-               "h:mm:ss a zzzz",
-               "h:mm:ss a z",
-               "h:mm:ss a",
-               "h:mm a",
-            };
+        final String[] metaValue_generic_TimePatterns = new String[] {
+            "h:mm:ss a zzzz",
+            "h:mm:ss a z",
+            "h:mm:ss a",
+            "h:mm a",
+        };
         final Object[][] data = new Object[][] {
-            { "buddhist.TimePatterns", metaValue_TimePatterns },
-            { "japanese.TimePatterns", metaValue_TimePatterns },
-            { "roc.TimePatterns", metaValue_TimePatterns },
-            { "TimePatterns", metaValue_TimePatterns },
-            { "islamic.TimePatterns", metaValue_TimePatterns },
+            { "buddhist.TimePatterns", metaValue_generic_TimePatterns },
+            { "japanese.TimePatterns", metaValue_generic_TimePatterns },
+            { "TimePatterns", metaValue_generic_TimePatterns },
+            { "roc.TimePatterns", metaValue_generic_TimePatterns },
+            { "islamic.TimePatterns", metaValue_generic_TimePatterns },
+            { "generic.TimePatterns", metaValue_generic_TimePatterns },
         };
         return data;
     }
