@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -70,66 +66,67 @@ import java.util.ListResourceBundle;
 public class FormatData_lkt extends ListResourceBundle {
     @Override
     protected final Object[][] getContents() {
+        final String[] metaValue_generic_DayNames = new String[] {
+            "A\u014bp\u00e9tuwak\u021fa\u014b",
+            "A\u014bp\u00e9tuwa\u014b\u017ei",
+            "A\u014bp\u00e9tunu\u014bpa",
+            "A\u014bp\u00e9tuyamni",
+            "A\u014bp\u00e9tutopa",
+            "A\u014bp\u00e9tuzapta\u014b",
+            "Ow\u00e1\u014bgyu\u017ea\u017eapi",
+        };
+        final String[] metaValue_generic_DayNarrows = new String[] {
+            "A",
+            "W",
+            "N",
+            "Y",
+            "T",
+            "Z",
+            "O",
+        };
+        final String[] metaValue_generic_TimePatterns = new String[] {
+            "h:mm:ss a zzzz",
+            "h:mm:ss a z",
+            "h:mm:ss a",
+            "h:mm a",
+        };
         final String[] metaValue_MonthNames = new String[] {
-               "Wi\u00f3the\u021fika W\u00ed",
-               "Thiy\u00f3\u021feyu\u014bka W\u00ed",
-               "I\u0161t\u00e1wi\u010dhayaza\u014b W\u00ed",
-               "P\u021fe\u017e\u00edt\u021fo W\u00ed",
-               "\u010cha\u014bw\u00e1pet\u021fo W\u00ed",
-               "W\u00edpazuk\u021fa-wa\u0161t\u00e9 W\u00ed",
-               "\u010cha\u014bp\u021f\u00e1sapa W\u00ed",
-               "Was\u00fat\u021fu\u014b W\u00ed",
-               "\u010cha\u014bw\u00e1pe\u01e7i W\u00ed",
-               "\u010cha\u014bw\u00e1pe-kasn\u00e1 W\u00ed",
-               "Wan\u00edyetu W\u00ed",
-               "T\u021fah\u00e9kap\u0161u\u014b W\u00ed",
-               "",
-            };
-        final String[] metaValue_DayNames = new String[] {
-               "A\u014bp\u00e9tuwak\u021fa\u014b",
-               "A\u014bp\u00e9tuwa\u014b\u017ei",
-               "A\u014bp\u00e9tunu\u014bpa",
-               "A\u014bp\u00e9tuyamni",
-               "A\u014bp\u00e9tutopa",
-               "A\u014bp\u00e9tuzapta\u014b",
-               "Ow\u00e1\u014bgyu\u017ea\u017eapi",
-            };
-        final String[] metaValue_DayNarrows = new String[] {
-               "A",
-               "W",
-               "N",
-               "Y",
-               "T",
-               "Z",
-               "O",
-            };
-        final String[] metaValue_TimePatterns = new String[] {
-               "h:mm:ss a zzzz",
-               "h:mm:ss a z",
-               "h:mm:ss a",
-               "h:mm a",
-            };
+            "Wi\u00f3the\u021fika W\u00ed",
+            "Thiy\u00f3\u021feyu\u014bka W\u00ed",
+            "I\u0161t\u00e1wi\u010dhayaza\u014b W\u00ed",
+            "P\u021fe\u017e\u00edt\u021fo W\u00ed",
+            "\u010cha\u014bw\u00e1pet\u021fo W\u00ed",
+            "W\u00edpazuk\u021fa-wa\u0161t\u00e9 W\u00ed",
+            "\u010cha\u014bp\u021f\u00e1sapa W\u00ed",
+            "Was\u00fat\u021fu\u014b W\u00ed",
+            "\u010cha\u014bw\u00e1pe\u01e7i W\u00ed",
+            "\u010cha\u014bw\u00e1pe-kasn\u00e1 W\u00ed",
+            "Wan\u00edyetu W\u00ed",
+            "T\u021fah\u00e9kap\u0161u\u014b W\u00ed",
+            "",
+        };
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
             { "field.year", "\u00d3mak\u021fa" },
-            { "TimePatterns", metaValue_TimePatterns },
-            { "islamic.DayNarrows", metaValue_DayNarrows },
-            { "japanese.DayNames", metaValue_DayNames },
-            { "japanese.DayAbbreviations", metaValue_DayNames },
-            { "DayNames", metaValue_DayNames },
+            { "TimePatterns", metaValue_generic_TimePatterns },
+            { "islamic.DayNarrows", metaValue_generic_DayNarrows },
+            { "japanese.DayNames", metaValue_generic_DayNames },
+            { "japanese.DayAbbreviations", metaValue_generic_DayNames },
+            { "DayNames", metaValue_generic_DayNames },
             { "field.month", "W\u00ed" },
+            { "generic.DayNarrows", metaValue_generic_DayNarrows },
             { "field.second", "Okp\u00ed" },
+            { "japanese.TimePatterns", metaValue_generic_TimePatterns },
             { "roc.MonthNames", metaValue_MonthNames },
-            { "japanese.TimePatterns", metaValue_TimePatterns },
             { "field.week", "Ok\u00f3" },
-            { "DayAbbreviations", metaValue_DayNames },
-            { "DayNarrows", metaValue_DayNarrows },
+            { "DayAbbreviations", metaValue_generic_DayNames },
+            { "DayNarrows", metaValue_generic_DayNarrows },
+            { "roc.DayNarrows", metaValue_generic_DayNarrows },
             { "japanese.MonthNames", metaValue_MonthNames },
-            { "roc.DayNarrows", metaValue_DayNarrows },
-            { "roc.DayNames", metaValue_DayNames },
-            { "standalone.DayAbbreviations", metaValue_DayNames },
+            { "roc.DayNames", metaValue_generic_DayNames },
+            { "standalone.DayAbbreviations", metaValue_generic_DayNames },
             { "roc.MonthAbbreviations", metaValue_MonthNames },
-            { "islamic.DayNames", metaValue_DayNames },
+            { "islamic.DayNames", metaValue_generic_DayNames },
             { "DatePatterns",
                 new String[] {
                     "EEEE, MMMM d, y",
@@ -138,12 +135,13 @@ public class FormatData_lkt extends ListResourceBundle {
                     "M/d/yy",
                 }
             },
-            { "buddhist.DayAbbreviations", metaValue_DayNames },
+            { "buddhist.DayAbbreviations", metaValue_generic_DayNames },
             { "field.weekday", "Ok\u00f3-a\u014bp\u00e9tu" },
-            { "islamic.TimePatterns", metaValue_TimePatterns },
+            { "islamic.TimePatterns", metaValue_generic_TimePatterns },
+            { "generic.TimePatterns", metaValue_generic_TimePatterns },
+            { "standalone.DayNames", metaValue_generic_DayNames },
             { "MonthAbbreviations", metaValue_MonthNames },
             { "buddhist.MonthNames", metaValue_MonthNames },
-            { "standalone.DayNames", metaValue_DayNames },
             { "latn.NumberElements",
                 new String[] {
                     ".",
@@ -162,13 +160,15 @@ public class FormatData_lkt extends ListResourceBundle {
                 }
             },
             { "field.hour", "Ow\u00e1p\u021fe" },
+            { "generic.DayAbbreviations", metaValue_generic_DayNames },
+            { "buddhist.DayNames", metaValue_generic_DayNames },
+            { "buddhist.TimePatterns", metaValue_generic_TimePatterns },
             { "japanese.MonthAbbreviations", metaValue_MonthNames },
-            { "buddhist.DayNames", metaValue_DayNames },
-            { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "field.minute", "Ow\u00e1p\u021fe o\u021f\u02bc\u00e1\u014bk\u021fo" },
+            { "islamic.DayAbbreviations", metaValue_generic_DayNames },
+            { "generic.DayNames", metaValue_generic_DayNames },
             { "standalone.MonthNames", metaValue_MonthNames },
             { "standalone.MonthAbbreviations", metaValue_MonthNames },
-            { "islamic.DayAbbreviations", metaValue_DayNames },
             { "latn.NumberPatterns",
                 new String[] {
                     "#,##0.###",
@@ -177,9 +177,9 @@ public class FormatData_lkt extends ListResourceBundle {
                     "",
                 }
             },
-            { "buddhist.DayNarrows", metaValue_DayNarrows },
-            { "japanese.DayNarrows", metaValue_DayNarrows },
-            { "roc.TimePatterns", metaValue_TimePatterns },
+            { "buddhist.DayNarrows", metaValue_generic_DayNarrows },
+            { "japanese.DayNarrows", metaValue_generic_DayNarrows },
+            { "roc.TimePatterns", metaValue_generic_TimePatterns },
         };
         return data;
     }
