@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -244,10 +244,11 @@ public class LocaleNames_is extends OpenListResourceBundle {
             { "GT", "Gvatemala" },
             { "GU", "Gvam" },
             { "GW", "G\u00ednea-Biss\u00e1" },
+            { "rhg", "rohingja" },
             { "tli", "tlingit" },
             { "tlh", "klingonska" },
             { "GY", "Gv\u00e6jana" },
-            { "ckb", "sorani-k\u00fard\u00edska" },
+            { "ckb", "mi\u00f0k\u00fard\u00edska" },
             { "zxx", "ekkert tungum\u00e1laefni" },
             { "de_AT", "austurr\u00edsk \u00fe\u00fdska" },
             { "HK", "s\u00e9rstj\u00f3rnarsv\u00e6\u00f0i\u00f0 Hong Kong" },
