@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -70,7 +66,10 @@ import sun.util.resources.OpenListResourceBundle;
 public class LocaleNames_sd extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
+        final String metaValue_CA = "\u06aa\u064a\u0646\u064a\u068a\u0627";
         final String metaValue_FJ = "\u0641\u062c\u064a";
+        final String metaValue_HU = "\u0647\u0646\u06af\u0631\u064a";
+        final String metaValue_LU = "\u0644\u06af\u0632\u0645\u0628\u0631\u06af";
         final String metaValue_NU = "\u0646\u0648\u0648\u064a";
         final String metaValue_TV = "\u062a\u0648\u0627\u0644\u0648";
         final String metaValue_ar = "\u0639\u0631\u0628\u064a";
@@ -84,7 +83,6 @@ public class LocaleNames_sd extends OpenListResourceBundle {
         final String metaValue_ko = "\u06aa\u0648\u0631\u064a\u0627\u0626\u064a";
         final String metaValue_la = "\u0644\u0627\u0637\u064a\u0646\u064a";
         final String metaValue_lo = "\u0644\u0627\u0626\u0648";
-        final String metaValue_ml = "\u0645\u0644\u064a\u0627\u0644\u0645";
         final String metaValue_mn = "\u0645\u0646\u06af\u0648\u0644\u064a";
         final String metaValue_or = "\u0627\u0648\u068a\u064a\u0627";
         final String metaValue_si = "\u0633\u0646\u0647\u0627\u0644\u0627";
@@ -96,6 +94,7 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "mwl", "\u0645\u0631\u0627\u0646\u068a\u064a\u0632" },
             { "Zsym", "\u0646\u0634\u0627\u0646\u064a\u0648\u0646" },
             { "Zsye", "\u0627\u064a\u0645\u0648\u062c\u064a" },
+            { "ccp", "\u0686\u0645\u06aa\u0627" },
             { "tem", "\u062a\u0645\u0646\u064a" },
             { "teo", "\u062a\u064a\u0633\u0648" },
             { "rap", "\u0631\u064a\u067e\u0646\u0648\u0626\u064a" },
@@ -104,9 +103,9 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "tet", "\u062a\u064a\u062a\u0645" },
             { "AD", "\u0627\u0646\u062f\u0648\u0631\u0627" },
             { "AE", "\u0645\u062a\u062d\u062f\u0647 \u0639\u0631\u0628 \u0627\u0645\u0627\u0631\u0627\u062a" },
-            { "nl_BE", "\u0641\u0644\u06cc\u0645\u0634" },
+            { "nl_BE", "\u0641\u0644\u064a\u0645\u0634" },
             { "AF", "\u0627\u0641\u063a\u0627\u0646\u0633\u062a\u0627\u0646" },
-            { "AG", "\u0627\u0646\u067d\u064a\u06af\u0626\u0627 \u0648 \u0628\u0631\u0628\u0648\u062f\u0627" },
+            { "AG", "\u0627\u0646\u067d\u064a\u06af\u0627 \u06fd \u0628\u0627\u0631\u0628\u0648\u068a\u0627" },
             { "type.ca.ethiopic", "\u0627\u064a\u067f\u0648\u067e\u064a\u0627\u0626\u064a \u06aa\u0626\u0644\u064a\u0646\u068a\u0631" },
             { "AI", "\u0627\u0646\u06af\u0648\u064a\u0644\u0627" },
             { "AL", "\u0627\u0644\u0628\u0627\u0646\u064a\u0627" },
@@ -115,18 +114,18 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "AQ", "\u0627\u0646\u067d\u0627\u0631\u06aa\u067d\u064a\u06aa\u0627" },
             { "AR", "\u0627\u0631\u062c\u0646\u067d\u064a\u0646\u0627" },
             { "AS", "\u0622\u0645\u0631\u064a\u06aa\u064a \u0633\u0627\u0645\u0648\u0627" },
-            { "AT", "\u0622\u0634\u067d\u0631\u064a\u0627" },
+            { "AT", "\u0622\u0633\u067d\u0631\u064a\u0627" },
             { "AU", "\u0622\u0633\u067d\u0631\u064a\u0644\u064a\u0627" },
             { "AW", "\u0639\u0631\u0648\u0628\u0627" },
             { "en_US", "\u0622\u0645\u0631\u064a\u06aa\u064a \u0627\u0646\u06af\u0631\u064a\u0632\u064a" },
             { "AX", "\u0627\u0644\u0646\u062f \u067b\u064a\u067d" },
             { "AZ", "\u0622\u0630\u0631\u0628\u0627\u0626\u064a\u062c\u0627\u0646" },
-            { "BA", "\u0628\u0648\u0633\u0646\u06cc\u0627 \u0627\u0648\u0631 \u0647\u0631\u0632\u06cc\u06af\u0648\u06cc\u0646\u0627" },
+            { "BA", "\u0628\u0648\u0633\u0646\u064a\u0627 \u06fd \u06be\u0631\u0632\u064a\u06af\u0648\u064a\u0646\u0627" },
             { "BB", "\u0628\u0627\u0631\u0628\u068a\u0648\u0633" },
             { "ceb", "\u0633\u0628\u0648\u0627\u0646\u0648" },
             { "BD", "\u0628\u0646\u06af\u0644\u0627\u062f\u064a\u0634" },
             { "kum", "\u06aa\u0648\u0645\u06aa" },
-            { "BE", "\u0622\u0633\u067d\u0631\u064a\u0627" },
+            { "BE", "\u0628\u064a\u0644\u062c\u064a\u0645" },
             { "BF", "\u0628\u0631\u06aa\u064a\u0646\u0627 \u0641\u0627\u0633\u0648" },
             { "BG", "\u0628\u0644\u063a\u0627\u0631\u064a\u0627" },
             { "BH", "\u0628\u062d\u0631\u064a\u0646" },
@@ -139,7 +138,7 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "BO", "\u0628\u0648\u0644\u064a\u0648\u064a\u0627" },
             { "BQ", "\u06aa\u064a\u0631\u064a\u0628\u064a\u0646 \u0646\u064a\u062f\u0631\u0644\u064a\u0646\u068a" },
             { "BR", "\u0628\u0631\u0627\u0632\u064a\u0644" },
-            { "BS", "\u0628\u0647\u0627\u0645\u0627\u0633" },
+            { "BS", "\u0628\u0627\u0647\u0627\u0645\u0627\u0633" },
             { "xog", "\u0633\u0648\u06af\u0627" },
             { "BT", "\u0680\u0648\u067d\u0627\u0646" },
             { "BV", "\u0628\u0648\u0648\u067d \u067b\u064a\u067d" },
@@ -148,21 +147,21 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "BZ", "\u0628\u064a\u0644\u064a\u0632" },
             { "type.ca.persian", "\u0641\u0627\u0631\u0633\u064a \u06aa\u0626\u0644\u064a\u0646\u068a\u0631" },
             { "type.nu.hebr", "\u0639\u0628\u0631\u0627\u0646\u064a \u0627\u0646\u06af" },
-            { "CA", "\u06aa\u0626\u0646\u0627\u068a\u0627" },
+            { "CA", metaValue_CA },
             { "CC", "\u06aa\u0648\u06aa\u0648\u0633 \u067b\u064a\u067d" },
             { "mzn", "\u0645\u0632\u064a\u0646\u062f\u0631\u0627\u0646\u064a" },
             { "CD", "\u06aa\u0627\u0646\u06af\u0648 -\u06aa\u0646\u0634\u0627\u0633\u0627" },
             { "CF", "\u0648\u0686 \u0622\u0641\u0631\u064a\u0642\u064a \u062c\u0645\u0647\u0648\u0631\u064a\u0647" },
             { "CG", "\u06aa\u0627\u0646\u06af\u0648 - \u0628\u0631\u0627\u0632\u0627\u0648\u06cc\u0644" },
-            { "CH", "\u0633\u0626\u064a\u067d\u0631\u0632\u0644\u064a\u0646\u068a" },
-            { "CI", "\u0622\u0626\u064a\u0648\u0631\u064a \u06aa\u0646\u0627\u0631\u0648" },
+            { "CH", "\u0633\u0648\u0626\u0632\u0631\u0644\u064a\u0646\u068a" },
+            { "CI", "\u06aa\u0648\u067d \u068a\u064a \u0648\u0627\u0631" },
             { "CK", "\u06aa\u0648\u06aa \u067b\u064a\u067d" },
             { "CL", "\u0686\u0644\u064a" },
             { "CM", "\u06aa\u064a\u0645\u0631\u0648\u0646" },
             { "CN", "\u0686\u064a\u0646" },
             { "CO", "\u06aa\u0648\u0644\u0645\u0628\u064a\u0627" },
             { "CP", "\u06aa\u0644\u067e\u0631\u067d\u0646 \u067b\u064a\u067d" },
-            { "CR", "\u06aa\u0648\u0633\u067d\u0627 \u0631\u06aa\u0627" },
+            { "CR", "\u06aa\u0648\u0633\u067d\u0627 \u0631\u064a\u06aa\u0627" },
             { "CU", "\u06aa\u064a\u0648\u0628\u0627" },
             { "CV", "\u06aa\u064a\u067e \u0648\u0631\u062f\u064a" },
             { "CW", "\u06aa\u064a\u0648\u0631\u0627\u0633\u0627\u0626\u0648" },
@@ -215,9 +214,8 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "FO", "\u0641\u0627\u0631\u0648 \u067b\u064a\u067d" },
             { "Taml", metaValue_ta },
             { "FR", "\u0641\u0631\u0627\u0646\u0633" },
-            { "root", "\u0631\u0648\u067d" },
             { "GA", "\u06af\u0628\u0648\u0646" },
-            { "GB", "\u0628\u0631\u0637\u0627\u0646\u064a\u0647" },
+            { "GB", "\u0628\u0631\u0637\u0627\u0646\u064a\u06c1" },
             { "pcm", "\u0646\u0627\u0626\u064a\u062c\u0631\u064a\u0646 \u067e\u062c\u0646" },
             { "GD", "\u06af\u0631\u064a\u0646\u068a\u0627" },
             { "GE", "\u062c\u0627\u0631\u062c\u064a\u0627" },
@@ -240,14 +238,14 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "ckb", "\u0645\u0631\u06aa\u0632\u064a \u06aa\u0631\u062f\u0634" },
             { "zxx", "\u06aa\u0648\u0626\u064a \u067b\u0648\u0644\u064a \u062c\u0648 \u0645\u0648\u0627\u062f \u06aa\u0648\u0646\u0647\u064a" },
             { "de_AT", "\u0622\u0633\u067d\u0631\u064a\u0627\u0626\u064a \u062c\u0631\u0645\u0646" },
-            { "HK", "\u0647\u0627\u0646\u06af \u06aa\u0627\u0646\u06af" },
+            { "HK", "\u0647\u0627\u0646\u06af \u06aa\u0627\u0646\u06af SAR" },
             { "HM", "\u0647\u0631\u068a \u06fd \u0645\u06aa\u068a\u0648\u0646\u0644\u068a \u067b\u064a\u067d" },
             { "HN", "\u0647\u0646\u068a\u0648\u0631\u0633" },
             { "HR", "\u06aa\u0631\u0648\u0626\u064a\u0634\u064a\u0627" },
             { "agq", "\u0627\u06af\u0647\u064a\u0645" },
             { "gsw", "\u0633\u0648\u0626\u0633 \u062c\u0631\u0645\u0646" },
             { "HT", "\u0647\u064a\u067d\u064a" },
-            { "HU", "\u0686\u064a\u06aa \u062c\u0647\u0645\u0648\u0631\u064a\u0647" },
+            { "HU", metaValue_HU },
             { "IC", "\u06aa\u064a\u0646\u0631\u064a \u067b\u064a\u067d" },
             { "ID", "\u0627\u0646\u068a\u0648\u0646\u064a\u0634\u064a\u0627" },
             { "IE", "\u0622\u0626\u0631\u0644\u064a\u0646\u068a" },
@@ -256,7 +254,7 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "zza", "\u0632\u0627\u0632\u0627" },
             { "IL", "\u0627\u0633\u0631\u0627\u0626\u064a\u0644" },
             { "IM", "\u0627\u0646\u0633\u0627\u0646\u0646 \u062c\u0648 \u067b\u064a\u067d" },
-            { "IN", "\u0627\u0646\u068a\u064a\u0627" },
+            { "IN", "\u0680\u0627\u0631\u062a" },
             { "IO", "\u0628\u0631\u0637\u0627\u0646\u0648\u064a \u0647\u0646\u062f\u064a \u0633\u0645\u0646\u068a \u062e\u0637\u0648" },
             { "IQ", "\u0639\u0631\u0627\u0642" },
             { "IR", "\u0627\u064a\u0631\u0627\u0646" },
@@ -264,6 +262,7 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "IT", "\u0627\u067d\u0644\u064a" },
             { "Zmth", "\u0631\u064a\u0627\u0636\u064a \u062c\u0648\u0646 \u0646\u0634\u0627\u0646\u064a\u0648\u0646" },
             { "type.nu.thai", "\u067f\u0627\u0626\u064a \u0639\u062f\u062f" },
+            { "%%POSIX", "\u06aa\u0645\u067e\u064a\u0648\u067d\u0631" },
             { "type.nu.beng", "\u0628\u0646\u06af\u0644\u0627 \u0639\u062f\u062f" },
             { "JE", "\u062c\u0631\u0633\u064a" },
             { "type.ca.islamic", "\u0627\u0633\u0644\u0627\u0645\u064a \u06aa\u0626\u0644\u064a\u0646\u068a\u0631" },
@@ -297,12 +296,13 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "LB", "\u0644\u0628\u0646\u0627\u0646" },
             { "LC", "\u0633\u064a\u0646\u067d \u0644\u0648\u0633\u064a\u0627" },
             { "gwi", "\u06af\u0648\u0686\u0646" },
+            { "nds", "\u0644\u0648 \u062c\u0631\u0645\u0646" },
             { "LI", "\u0644\u0686\u064a \u067d\u064a\u0646\u0633\u067d\u064a\u0646" },
             { "LK", "\u0633\u0631\u064a \u0644\u0646\u06aa\u0627" },
             { "LR", "\u0644\u0627\u0626\u0628\u06cc\u0631\u06cc\u0627" },
             { "LS", "\u0644\u064a\u0633\u0648\u067f\u0648" },
             { "LT", "\u0644\u067f\u0648\u0646\u064a\u0627" },
-            { "LU", "\u0644\u06cc\u06af\u0632\u0645\u0628\u0631\u06af" },
+            { "LU", metaValue_LU },
             { "LV", "\u0644\u0627\u062a\u0648\u064a\u0627" },
             { "Kana", "\u06aa\u067d\u0627\u06aa\u0627\u0646\u0627" },
             { "LY", "\u0644\u0628\u064a\u0627" },
@@ -310,22 +310,22 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "vun", "\u0648\u0646\u062c\u0648" },
             { "lag", "\u0644\u0627\u0646\u06af\u064a" },
             { "Thaa", "\u067f\u0627\u0646\u0627" },
-            { "MA", "\u0645\u0648\u0631\u0648\u06aa\u0648" },
+            { "MA", "\u0645\u0631\u0627\u06aa\u0634" },
             { "MC", "\u0645\u0648\u0646\u0627\u06aa\u0648" },
             { "MD", "\u0645\u0627\u0644\u062f\u0648\u0648\u0627" },
             { "ME", "\u0645\u0648\u0646\u067d\u064a \u0646\u064a\u06af\u0631\u0648" },
             { "MF", "\u0633\u064a\u0646\u067d \u0645\u0627\u0631\u067d\u0646" },
-            { "MG", "\u0645\u062f\u0627\u06af\u064a\u0633\u06aa\u0631" },
+            { "MG", "\u0645\u062f\u06af\u0627\u0633\u06aa\u0631" },
             { "Thai", metaValue_th },
-            { "MH", "\u0645\u0627\u0631\u0634\u0644 \u0680\u064a\u067d" },
+            { "MH", "\u0645\u0627\u0631\u0634\u0644 \u067b\u064a\u067d" },
             { "ale", "\u0627\u0644\u064a\u0648\u067d" },
-            { "MK", "\u0645\u064a\u0633\u064a \u068a\u0648\u0646\u064a\u0627" },
+            { "MK", "\u0627\u062a\u0631 \u0645\u0642\u062f\u0648\u0646\u064a\u0627" },
             { "ML", "\u0645\u0627\u0644\u064a" },
             { "MM", "\u0645\u064a\u0627\u0646\u0645\u0627\u0631 (\u0628\u0631\u0645\u0627)" },
             { "MN", "\u0645\u0646\u06af\u0648\u0644\u064a\u0627" },
             { "new", "\u0646\u064a\u0648\u0627\u0631\u064a" },
-            { "MO", "\u0645\u06aa\u0627\u0626\u0648" },
-            { "MP", "\u0627\u062a\u0631 \u0645\u0631\u064a\u0646\u0627 \u067b\u064a\u067d" },
+            { "MO", "\u0645\u06aa\u0627\u0626\u0648 SAR \u0686\u064a\u0646" },
+            { "MP", "\u0627\u062a\u0631\u064a\u0627\u0646 \u0645\u0627\u0631\u064a\u0627\u0646\u0627 \u067b\u064a\u067d" },
             { "MQ", "\u0645\u0627\u0631\u062a\u064a\u0646\u06aa" },
             { "MR", "\u0645\u0648\u0631\u064a\u062a\u0627\u0646\u064a\u0627" },
             { "MS", "\u0645\u0648\u0646\u067d\u0633\u0631\u0627\u067d" },
@@ -339,7 +339,7 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "MY", "\u0645\u0644\u0627\u0626\u064a\u0634\u064a\u0627" },
             { "MZ", "\u0645\u0648\u0632\u0645\u0628\u06cc\u0642" },
             { "NA", "\u0646\u064a\u0645\u064a\u0628\u064a\u0627" },
-            { "202", "\u0633\u0628 \u0633\u0647\u0627\u0631\u0627 \u0622\u0641\u0631\u064a\u06aa\u0627" },
+            { "202", "\u0633\u0628-\u0633\u0647\u0627\u0631\u0627 \u0622\u0641\u0631\u064a\u06aa\u0627" },
             { "type.ca.hebrew", "\u0639\u0628\u0631\u0627\u0646\u064a \u06aa\u0626\u0644\u064a\u0646\u068a\u0631" },
             { "NC", "\u0646\u06cc\u0648 \u06aa\u0627\u0644\u06cc\u068a\u0648\u0646\u06cc\u0627" },
             { "NE", "\u0646\u0627\u0626\u064a\u062c\u0631" },
@@ -357,6 +357,7 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "OM", "\u0639\u0645\u0627\u0646" },
             { "anp", "\u0627\u0646\u062c\u064a\u06aa\u0627" },
             { "crs", "\u0633\u064a\u0633\u0644\u0648\u0627 \u06aa\u0631\u064a\u0626\u0648\u0644 \u0641\u0631\u0627\u0646\u0633\u064a" },
+            { "Xpeo", "\u0642\u062f\u064a\u0645 \u0641\u0627\u0631\u0633\u064a" },
             { "PA", "\u067e\u0646\u0627\u0645\u0627" },
             { "en_GB", "\u0628\u0631\u0637\u0627\u0646\u0648\u064a \u0627\u0646\u06af\u0631\u064a\u0632\u064a" },
             { "PE", "\u067e\u064a\u0631\u0648" },
@@ -369,7 +370,7 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "PM", "\u0633\u06cc\u0646\u067d \u067e\u06cc\u0626\u0631 \u0648 \u0645\u06cc\u06aa\u0648\u0626\u06cc\u0644\u0648\u0646" },
             { "PN", "\u067e\u067d\u06aa\u0626\u0631\u0646 \u067b\u064a\u067d" },
             { "PR", "\u067e\u064a\u0648\u0626\u0631\u067d\u0648 \u0631\u064a\u06aa\u0648" },
-            { "PS", "\u0641\u0644\u0633\u0637\u06cc\u0646\u06cc" },
+            { "PS", "\u0641\u0644\u0633\u0637\u064a\u0646\u064a \u0639\u0644\u0627\u0626\u0642\u0627" },
             { "PT", "\u067e\u0631\u062a\u06af\u0627\u0644" },
             { "PW", "\u067e\u0644\u0627\u0626\u0648" },
             { "nia", "\u0646\u064a\u0627\u0633" },
@@ -388,12 +389,12 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "RE", "\u0631\u064a \u064a\u0648\u0646\u064a\u0646" },
             { "005", "\u068f\u06a9\u06bb \u0622\u0645\u0631\u064a\u06aa\u0627" },
             { "jbo", "\u0644\u0648\u062c\u0628\u064a\u0646" },
-            { "009", "\u0633\u0627\u0645\u0648\u0646\u068a\u064a" },
+            { "009", "\u0627\u0648\u0634\u0646\u064a\u0627" },
             { "RO", "\u0631\u0648\u0645\u0627\u0646\u064a\u0627" },
             { "RS", "\u0633\u0631\u0628\u064a\u0627" },
             { "RU", "\u0631\u0648\u0633" },
             { "RW", "\u0631\u0648\u0627\u0646\u068a\u0627" },
-            { "SA", "\u0633\u0639\u0648\u062f\u06cc \u0639\u0631\u0628" },
+            { "SA", "\u0633\u0639\u0648\u062f\u064a \u0639\u0631\u0628" },
             { "SB", "\u0633\u0648\u0644\u0648\u0645\u0648\u0646 \u067b\u064a\u067d\u064e" },
             { "twq", "\u062a\u0633\u0627\u0648\u06aa\u064a" },
             { "011", "\u0627\u0648\u0644\u0647\u0647 \u0622\u0641\u0631\u064a\u0642\u0627" },
@@ -402,14 +403,15 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "013", "\u0648\u0686 \u0622\u0645\u0631\u064a\u06aa\u0627" },
             { "SE", "\u0633\u0648\u0626\u064a\u068a\u0646" },
             { "014", "\u0627\u0648\u0680\u0631 \u0622\u0641\u0631\u064a\u06aa\u0627" },
-            { "015", "\u0627\u062a\u0631\u064a\u0646 \u0622\u0641\u0631\u064a\u06aa\u0627" },
-            { "SG", "\u0633\u064a\u0646\u06af\u0627\u067e\u0648\u0631" },
+            { "015", "\u0627\u062a\u0631 \u0622\u0641\u0631\u064a\u06aa\u0627" },
+            { "SG", "\u0633\u0646\u06af\u0627\u067e\u0648\u0631" },
             { "SH", "\u0633\u064a\u0646\u067d \u06be\u064a\u0644\u064a\u0646\u0627" },
             { "type.lb.strict", "\u0633\u062e\u062a \u0644\u0627\u0626\u0646 \u067d\u0648\u0699 \u0627\u0646\u062f\u0627\u0632" },
             { "017", "\u0648\u0686 \u0622\u0641\u0631\u064a\u06aa\u0627" },
             { "SI", "\u0633\u0644\u0648\u06cc\u0646\u06cc\u0627" },
             { "018", "\u068f\u0627\u06a9\u06bb\u064a \u0622\u0645\u0631\u064a\u06aa\u0627" },
             { "SJ", "\u0633\u0648\u0627\u0644\u0628\u0627\u0631\u068a \u06fd \u062c\u0627\u0646 \u0645\u0627\u06cc\u0646" },
+            { "019", "\u0622\u0645\u0631\u064a\u06aa\u0627" },
             { "SK", "\u0633\u0644\u0648\u0648\u0627\u06aa\u064a\u0627" },
             { "SL", "\u0633\u064a\u0631\u0627 \u0644\u064a\u0648\u0646" },
             { "SM", "\u0633\u06cc\u0646 \u0645\u0631\u06cc\u0646\u0648" },
@@ -424,7 +426,7 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "SV", "\u0627\u0644 \u0633\u0644\u0648\u0627\u068a\u0648\u0631" },
             { "SX", "\u0633\u0646\u067d \u0645\u0627\u0631\u067d\u0646" },
             { "SY", "\u0634\u0627\u0645" },
-            { "SZ", "\u0633\u0648\u0627\u0632\u064a\u0644\u064a\u0646\u068a" },
+            { "SZ", "\u0627\u064a\u0633\u0648\u0627\u067d\u0646\u064a" },
             { "TA", "\u067d\u0631\u0633\u067d\u0646 \u062f\u0627 \u06aa\u0648\u0647\u0627" },
             { "asa", "\u0627\u0633\u0648" },
             { "type.ms.ussystem", "\u0622\u0645\u0631\u064a\u06aa\u0627 \u062c\u0648 \u0645\u0627\u067e\u06bb \u062c\u0648 \u0646\u0638\u0627\u0645" },
@@ -433,7 +435,7 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "yav", "\u064a\u0627\u0646\u06af \u0628\u064a\u0646" },
             { "TD", "\u0686\u0627\u068a" },
             { "TF", "\u0641\u0631\u0627\u0646\u0633\u064a\u0633\u064a \u068f\u0627\u06a9\u06bb\u064a \u0639\u0644\u0627\u0626\u0642\u0627" },
-            { "TG", "\u062a\u0648\u06af\u0648" },
+            { "TG", "\u067d\u0648\u06af\u0648" },
             { "TH", "\u067f\u0627\u0626\u064a\u0644\u064a\u0646\u062f" },
             { "TJ", "\u062a\u0627\u062c\u06aa\u0633\u062a\u0627\u0646" },
             { "029", "\u06aa\u064a\u0631\u064a\u0628\u064a\u0646" },
@@ -461,8 +463,8 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "UG", "\u064a\u0648\u06af\u0646\u068a\u0627" },
             { "039", "\u068f\u06a9\u06bb \u064a\u0648\u0631\u067e" },
             { "Sinh", metaValue_si },
-            { "UM", "\u0622\u0645\u0631\u064a\u06aa\u064a \u067b\u0627\u0647\u0631\u064a\u0648\u0646 \u067b\u064a\u067d" },
-            { "UN", "\u0627\u0642\u0648\u0627\u0645 \u0645\u062a\u062d\u062f\u0647" },
+            { "UM", "\u0622\u0645\u0631\u064a\u06aa\u064a \u062e\u0627\u0631\u062c\u064a \u067b\u064a\u067d" },
+            { "UN", "\u06af\u068f\u064a\u0644 \u0642\u0648\u0645\u0648\u0646" },
             { "US", "\u0622\u0645\u0631\u064a\u06aa\u0627 \u062c\u0648\u0646 \u06af\u068f\u064a\u0644 \u0631\u064a\u0627\u0633\u062a\u0648\u0646" },
             { "haw", "\u0647\u0648\u0627\u0626\u064a" },
             { "UY", "\u064a\u0648\u0631\u0648\u06af\u0648\u0621\u0650" },
@@ -472,7 +474,7 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "nnh", "\u0646\u063a\u064a\u0645\u0628\u0648\u0646" },
             { "VA", "\u0648\u064a\u067d\u06aa\u064a\u0646 \u0633\u067d\u064a" },
             { "VC", "\u0633\u06cc\u0646\u067d \u0648\u0646\u0633\u0646\u062a \u06fd \u06af\u0631\u06cc\u0646\u0627\u068a\u06cc\u0646\u0632" },
-            { "VE", "\u0648\u064a\u0646\u0632\u064a\u0644\u0627" },
+            { "VE", "\u0648\u064a\u0646\u0632\u0648\u064a\u0644\u0627" },
             { "VG", "\u0628\u0631\u0637\u0627\u0646\u0648\u064a \u0648\u0631\u062c\u0646 \u067b\u064a\u067d" },
             { "VI", "\u0622\u0645\u0631\u064a\u06aa\u064a \u0648\u0631\u062c\u0646 \u067b\u064a\u067d" },
             { "VN", "\u0648\u064a\u062a\u0646\u0627\u0645" },
@@ -482,13 +484,15 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "053", "\u0622\u0633\u067d\u0631\u06cc\u0644\u06cc\u0634\u06cc\u0627" },
             { "054", "\u0645\u06cc\u0644\u0627\u0646\u06cc\u0634\u06cc\u0627" },
             { "WF", "\u0648\u0627\u0644\u0633 \u06fd \u0641\u062a\u0648\u0646\u0627" },
-            { "057", "\u0645\u0627\u0626\u06a9\u0631\u0648\u0646\u06cc\u0634\u06cc\u0627\u0626\u064a" },
+            { "057", "\u0645\u0627\u0626\u06aa\u0631\u0648\u0646\u064a\u0634\u0627\u0626\u064a \u062e\u0637\u0648" },
             { "jgo", "\u0646\u063a\u0648\u0645\u0628\u0627" },
             { "lkt", "\u0644\u06aa\u0648\u067d\u0627" },
             { "wae", "\u0648\u0627\u0644\u0633\u0631" },
-            { "WS", "\u0633\u0645\u0648\u0626\u0627" },
+            { "WS", "\u0633\u0627\u0645\u0648\u0627" },
             { "wal", "\u0648\u0648\u0644\u0627\u064a\u067d\u0627" },
+            { "XA", "\u0633\u0648\u068a\u0648-\u0644\u0647\u062c\u0627" },
             { "war", "\u0648\u0627\u0631\u064a" },
+            { "XB", "\u0633\u0648\u068a\u0648-\u0628\u064a \u068a\u064a" },
             { "awa", "\u0627\u0648\u0627\u068c\u064a" },
             { "061", "\u067e\u0648\u0644\u06cc\u0646\u06cc\u0634\u06cc\u0627" },
             { "XK", "\u06aa\u0648\u0633\u0648\u0648\u0648" },
@@ -538,7 +542,7 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "fil", "\u0641\u0644\u067e\u0627\u0626\u0646\u064a" },
             { "hmn", "\u0645\u0648\u0646\u06af" },
             { "lus", "\u0645\u064a\u0632\u0648" },
-            { "ban", "\u0628\u0627\u0644\u064a" },
+            { "ban", "\u0628\u0627\u0644\u064a\u0646\u064a\u0633" },
             { "luy", "\u0644\u0648\u0647\u064a\u0627" },
             { "bas", "\u0628\u0627\u0633\u0627" },
             { "es_ES", "\u064a\u0648\u0631\u067e\u064a \u0627\u0633\u067e\u064a\u0646\u064a" },
@@ -558,7 +562,7 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "av", "\u0627\u0648\u064a\u0631\u0633" },
             { "ay", "\u0627\u06cc\u0645\u0627\u0631\u0627" },
             { "az", "\u0622\u0632\u0631\u0628\u0627\u0626\u064a\u062c\u0627\u0646\u064a" },
-            { "ba", "\u0628\u0634\u06aa\u0631" },
+            { "ba", metaValue_CA },
             { "be", "\u0628\u064a\u0644\u0627\u0631\u0648\u0633\u064a" },
             { "bg", "\u0628\u0644\u063a\u0627\u0631\u064a\u0627\u0626\u064a" },
             { "bi", "\u0628\u0633\u0644\u0627\u0645\u0627" },
@@ -600,17 +604,17 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "el", metaValue_el },
             { "en", "\u0627\u0646\u06af\u0631\u064a\u0632\u064a" },
             { "eo", "\u0627\u064a\u0633\u067e\u0631\u0627\u0646\u067d\u0648" },
-            { "es", "\u0627\u0633\u067e\u064a\u0646\u064a" },
+            { "es", "\u0647\u0633\u067e\u0627\u0646\u0648\u064a" },
             { "et", "\u0627\u064a\u0633\u062a\u0648\u0646\u0627\u0626\u064a" },
             { "Hanb", "\u0628\u0648\u067e\u0648\u0645\u0648\u0641\u0648 \u0633\u0627\u0646 \u0647\u064a\u0646" },
-            { "eu", "\u0628\u0627\u0633\u06aa\u064a" },
+            { "eu", "\u0628\u0627\u0633\u0642" },
             { "Hang", "\u0647\u0646\u06af\u0648\u0644" },
             { "shi", "\u062a\u064a\u0686\u0644 \u0647\u0627\u062a\u064a" },
             { "hsb", "\u0627\u067e\u0631 \u0633\u0631\u0628\u064a\u0627\u0626\u064a" },
             { "Hani", "\u0647\u064a\u0646" },
             { "shn", "\u0634\u0627\u0646" },
             { "fa", "\u0641\u0627\u0631\u0633\u064a" },
-            { "Hans", "\u0622\u0633\u0627\u0646 \u06aa\u064a\u0644" },
+            { "Hans", "\u0633\u0627\u062f\u064a" },
             { "type.nu.latn", "\u0645\u063a\u0631\u0628\u064a \u0639\u062f\u062f" },
             { "Hant", "\u0631\u0648\u0627\u064a\u062a\u064a" },
             { "ff", "\u0641\u0644\u0627\u0647\u0647" },
@@ -620,7 +624,7 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "yue", "\u06aa\u064a\u0646\u067d\u0648\u0646\u064a\u0632" },
             { "fo", "\u0641\u064a\u0631\u0648\u0627\u064a\u0633" },
             { "umb", "\u0627\u0648\u0645\u0628\u0646\u068a\u0648" },
-            { "fr", "\u0641\u0631\u0627\u0646\u0633\u064a" },
+            { "fr", "\u0641\u0631\u0627\u0646\u0633\u064a\u0633\u064a" },
             { "fy", "\u0645\u063a\u0631\u0628\u064a \u0641\u0631\u064a\u0634\u0646" },
             { "ga", "\u0622\u0626\u0631\u0634" },
             { "gd", "\u0627\u0633\u06aa\u0627\u067d\u0634 \u06af\u064a\u0644\u06aa" },
@@ -637,7 +641,7 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "bin", "\u0628\u0646\u064a" },
             { "hr", "\u06aa\u0631\u0648\u0634\u064a\u0627\u0626\u064a" },
             { "ht", "\u0647\u064a\u067d\u064a \u06aa\u0631\u0648\u0644\u064a" },
-            { "hu", "\u0647\u0646\u06af\u0631\u064a" },
+            { "hu", metaValue_HU },
             { "hy", "\u0627\u0631\u0645\u0627\u0646\u064a" },
             { "hz", "\u0647\u0631\u064a\u0631\u0648" },
             { "ia", "\u0627\u0646\u067d\u0631\u0644\u0646\u06af\u0626\u0627" },
@@ -651,7 +655,8 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "it", "\u0627\u0637\u0627\u0644\u0648\u064a" },
             { "iu", "\u0627\u0646\u0648 \u06aa\u062a\u0648\u062a" },
             { "ja", metaValue_ja },
-            { "Mlym", metaValue_ml },
+            { "Mlym", "\u0645\u0644\u0627\u064a\u0627\u0644\u0645" },
+            { "Sarb", "\u0642\u062f\u064a\u0645 \u068f\u0627\u06a9\u06bb\u064a \u0639\u0631\u0628\u064a" },
             { "sma", "\u068f\u06a9\u06bb \u0633\u0627\u0645\u064a" },
             { "jv", "\u062c\u0627\u0648\u0646\u064a\u0632" },
             { "mad", "\u0645\u062f\u0648\u0631\u0627\u0626\u064a" },
@@ -659,7 +664,7 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "mag", "\u0645\u06af\u0627\u0647\u064a" },
             { "mai", "\u0645\u064a\u067f\u0644\u064a" },
             { "smn", "\u0627\u0646\u0627\u0631\u064a \u0633\u0627\u0645\u064a" },
-            { "ka", "\u062c\u0627\u0631\u062c\u064a\u0646" },
+            { "ka", "\u062c\u0627\u0631\u062c\u064a\u0627\u0626\u064a" },
             { "bla", "\u0633\u06aa\u0633\u06aa\u0627" },
             { "mak", "\u0645\u06aa\u0627\u0633\u0631" },
             { "sms", "\u0627\u0633\u06aa\u0627\u067d \u0633\u0627\u0645\u064a" },
@@ -678,8 +683,9 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "kw", "\u06aa\u0648\u0631\u0646\u0634" },
             { "ky", "\u06aa\u0631\u063a\u064a\u0632" },
             { "snk", "\u0633\u0648\u0646\u064a\u0646\u06aa\u064a" },
+            { "Mult", "\u0645\u0644\u062a\u0627\u0646\u064a" },
             { "la", metaValue_la },
-            { "lb", "\u0644\u06af\u0632\u0645\u0628\u0631\u06af" },
+            { "lb", metaValue_LU },
             { "type.nu.mlym", "\u0645\u0644\u064a\u0627\u0644\u0645 \u0639\u062f\u062f" },
             { "lg", "\u06af\u0627\u0646\u062f\u0627" },
             { "li", "\u0644\u0645\u0628\u0631\u06af\u0634" },
@@ -696,7 +702,7 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "type.co.ducet", "\u068a\u0641\u0627\u0644\u067d \u064a\u0648\u0646\u064a \u06aa\u0648\u068a \u062a\u0631\u062a\u064a\u0628 \u0687\u0627\u0646\u067d\u064a" },
             { "mi", "\u0645\u0627\u0626\u0648\u0631\u064a" },
             { "mk", "\u0645\u064a\u0633\u064a \u068a\u0648\u0646\u064a\u0627\u0626\u064a" },
-            { "ml", metaValue_ml },
+            { "ml", "\u0645\u0644\u064a\u0627\u0644\u0645" },
             { "mn", metaValue_mn },
             { "mr", "\u0645\u0631\u0627\u067a\u064a" },
             { "ms", "\u0645\u0644\u064a" },
@@ -735,7 +741,7 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "pl", "\u067e\u0648\u0644\u0634" },
             { "type.ca.dangi", "\u062f\u0627\u0646\u06af\u064a \u06aa\u0626\u0644\u064a\u0646\u068a\u0631" },
             { "ps", "\u067e\u0634\u062a\u0648" },
-            { "pt", "\u067e\u0631\u062a\u06af\u0627\u0644\u064a" },
+            { "pt", "\u067e\u0648\u0631\u067d\u06af\u0644\u064a\u0632" },
             { "key.co", "\u062a\u0631\u062a\u064a\u0628 \u0687\u0627\u0646\u067d\u064a" },
             { "pt_BR", "\u0628\u0631\u0627\u0632\u064a\u0644\u064a \u067e\u0631\u062a\u06af\u0627\u0644\u064a" },
             { "kcg", "\u062a\u064a\u0627\u067e" },
@@ -775,7 +781,7 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "si", metaValue_si },
             { "sk", "\u0633\u0644\u0648\u0627\u06aa\u064a" },
             { "sl", "\u0633\u0644\u0648\u0648\u064a\u0646\u064a" },
-            { "sm", "\u0633\u0627\u0645\u0648\u0622\u0646" },
+            { "sm", "\u0633\u0645\u0648\u0626\u0627" },
             { "sn", "\u0634\u0648\u0646\u0627" },
             { "so", "\u0633\u0648\u0645\u0627\u0644\u064a" },
             { "type.nu.arab", "\u0639\u0631\u0628\u064a-\u0647\u0646\u062f\u064a \u0639\u062f\u062f" },
@@ -784,8 +790,9 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "ss", "\u0633\u0648\u0627\u062a\u064a" },
             { "type.cf.account", "\u0627\u06aa\u0627\u0626\u0648\u0646\u067d\u0646\u06af \u0633\u06aa\u0648 \u0641\u0627\u0631\u0645\u064a\u067d" },
             { "st", "\u068f\u06a9\u06bb \u0633\u0648\u067f\u064a" },
+            { "Java", "\u062c\u0627\u0648\u0627\u0646\u064a\u0632" },
             { "su", "\u0633\u0648\u068a\u0627\u0646\u064a" },
-            { "sv", "\u0633\u0648\u064a\u068a\u0646\u064a" },
+            { "sv", "\u0633\u0648\u064a\u068a\u0634" },
             { "sw", "\u0633\u0648\u0627\u062d\u064a\u0644\u064a" },
             { "type.nu.hantfin", "\u0631\u0648\u0627\u064a\u062a\u064a \u0686\u064a\u0646\u064a \u0645\u0627\u0644\u064a \u0627\u0646\u06af" },
             { "ibb", "\u0627\u0628\u064a\u0628\u064a\u0648" },
@@ -795,29 +802,30 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "143", "\u0648\u0686 \u0627\u064a\u0634\u064a\u0627" },
             { "te", metaValue_te },
             { "145", "\u0627\u0648\u0644\u0647\u0647 \u0627\u064a\u0634\u064a\u0627" },
-            { "tg", "\u062a\u0627\u062c\u06aa\u064a" },
+            { "tg", "\u062a\u0627\u062c\u06aa" },
             { "th", metaValue_th },
             { "ti", "\u062a\u06af\u0631\u064a\u0646\u064a\u0627\u0626\u064a" },
             { "bug", "\u0628\u06af\u0646\u064a\u0632" },
             { "kfo", "\u06aa\u0648\u0631\u0648" },
             { "en_CA", "\u06aa\u064a\u0646\u064a\u068a\u064a\u0627\u0626\u064a \u0627\u0646\u06af\u0631\u064a\u0632\u064a" },
-            { "tk", "\u062a\u0631\u06aa\u0645\u0627\u0646\u064a" },
+            { "tk", "\u062a\u0631\u06aa\u0645\u064a\u0646" },
             { "tn", "\u062a\u0633\u0648\u0627\u0646\u0627" },
             { "to", "\u062a\u0648\u0646\u06af\u0646" },
             { "dyo", "\u062c\u0648\u0644\u0627 \u0641\u0648\u0646\u064a" },
             { "type.nu.jpan", "\u062c\u0627\u067e\u0627\u0646\u064a \u0627\u0646\u06af" },
-            { "tr", "\u062a\u0631\u06aa" },
+            { "tr", "\u062a\u0631\u06aa\u0634" },
             { "ts", "\u0633\u0648\u0646\u06af\u0627" },
             { "swb", "\u06aa\u0645\u0648\u0631\u064a\u0646" },
-            { "tt", "\u062a\u0627\u062a\u0631\u064a" },
+            { "tt", "\u062a\u0627\u062a\u0627\u0631" },
             { "ty", "\u062a\u0627\u0647\u064a\u062a\u064a" },
             { "150", "\u064a\u0648\u0631\u067e" },
             { "151", "\u0627\u0648\u0680\u0631 \u064a\u0648\u0631\u067e" },
             { "154", "\u0627\u062a\u0631\u064a\u0646 \u064a\u0648\u0631\u067e" },
             { "dzg", "\u062f\u0632\u0627\u06af\u0627" },
-            { "155", "\u0627\u0648\u0644\u0647\u0646\u062f\u064a \u064a\u0648\u0631\u067e" },
+            { "155", "\u0627\u0648\u0644\u0647\u0647 \u064a\u0648\u0631\u067e" },
             { "ug", "\u064a\u0648\u063a\u0648\u0631" },
             { "Kore", metaValue_ko },
+            { "Ital", "\u0642\u062f\u064a\u0645 \u0627\u0637\u0627\u0644\u0648\u064a" },
             { "Zyyy", "\u06aa\u0627\u0645\u0646" },
             { "uk", "\u064a\u0648\u06aa\u0631\u0627\u0646\u064a" },
             { "ur", "\u0627\u0631\u062f\u0648" },
@@ -835,7 +843,7 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "wa", "\u0648\u0644\u0648\u0646" },
             { "syr", "\u0634\u0627\u0645\u064a" },
             { "Grek", metaValue_el },
-            { "wo", "\u0648\u0648\u0644\u0641" },
+            { "wo", "\u0648\u0648\u0644\u0648\u0641" },
             { "zgh", "\u0645\u0639\u064a\u0627\u0631\u064a \u0645\u0631\u0627\u06aa\u0634\u064a \u062a\u0627\u0645\u0627\u0632\u0627\u0626\u064a\u067d" },
             { "ar_001", "\u062c\u062f\u064a\u062f \u0645\u0639\u064a\u0627\u0631\u064a \u0639\u0631\u0628\u064a" },
             { "Mong", metaValue_mn },
@@ -851,6 +859,7 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "yi", "\u064a\u062f\u0634" },
             { "mos", "\u0645\u0648\u0633\u064a" },
             { "yo", "\u064a\u0648\u0631\u0648\u0628\u0627" },
+            { "es_MX", "\u0645\u064a\u06aa\u0633\u064a\u06aa\u064a\u0646 \u0627\u0633\u067e\u064a\u0646\u064a" },
             { "vai", "\u064a\u0627" },
             { "kln", "\u06aa\u064a\u0644\u064a\u0646 \u062c\u0646" },
             { "zh", "\u0686\u064a\u0646\u064a" },
@@ -862,7 +871,6 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "type.nu.jpanfin", "\u062c\u0627\u067e\u0627\u0646\u064a \u0645\u0627\u0644\u064a \u0627\u0646\u06af" },
             { "gez", "\u062c\u064a\u0632" },
             { "ebu", "\u0627\u064a\u0645\u0628\u064a\u0648" },
-            { "zh_Hans", "\u0622\u0633\u0627\u0646 \u0686\u06cc\u0646\u06cc" },
             { "kok", "\u06aa\u0648\u0646\u06aa\u064a" },
             { "zh_Hant", "\u0631\u0648\u0627\u064a\u062a\u064a \u0686\u064a\u0646\u064a" },
             { "kpe", "\u06aa\u067e\u064a\u0644" },
@@ -877,6 +885,7 @@ public class LocaleNames_sd extends OpenListResourceBundle {
             { "type.nu.tamldec", "\u062a\u0627\u0645\u0644 \u0639\u062f\u062f" },
             { "krc", "\u06aa\u0631\u0627\u0686\u064a \u0628\u0627\u0644\u06aa\u0631" },
             { "inh", "\u0627\u0646\u06af\u0634" },
+            { "fa_AF", "\u062f\u0631\u064a" },
             { "krl", "\u06aa\u0631\u064a\u0644\u0626\u064a\u0646" },
             { "efi", "\u0627\u064a\u0641\u06aa" },
             { "key.nu", "\u0627\u0646\u06af" },
