@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -784,6 +784,7 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "raj", "rad\u017eastan\u010dina" },
             { "rap", "rapanuj\u010dina" },
             { "rar", "rarotongsk\u00e1 maorij\u010dina" },
+            { "rhg", "rohing\u010dina" },
             { "rof", "rombo" },
             { "rom", "r\u00f3m\u010dina" },
             { "rup", "arumun\u010dina" },
@@ -925,7 +926,6 @@ public class LocaleNames_sk extends OpenListResourceBundle {
             { "Zxxx", "bez z\u00e1pisu" },
             { "Zyyy", "v\u0161eobecn\u00e9" },
             { "Zzzz", "nezn\u00e1me p\u00edsmo" },
-            { "root", "kore\u0148" },
             { "de_AT", "nem\u010dina (rak\u00faska)" },
             { "de_CH", "nem\u010dina (\u0161vaj\u010diarska spisovn\u00e1)" },
             { "en_AU", "angli\u010dtina (austr\u00e1lska)" },
