@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -95,6 +91,7 @@ public class LocaleNames_sw extends OpenListResourceBundle {
             { "mwl", "Kimirandi" },
             { "Zsym", "Alama" },
             { "Zsye", "Emoji" },
+            { "ccp", "Kichakma" },
             { "egy", "Kimisri" },
             { "tem", "Kitemne" },
             { "teo", "Kiteso" },
@@ -109,7 +106,7 @@ public class LocaleNames_sw extends OpenListResourceBundle {
             { "AG", "Antigua na Barbuda" },
             { "type.ca.ethiopic", "Kalenda ya Kiethiopia" },
             { "AI", "Anguilla" },
-            { "key.tz", "Ukanda Saa" },
+            { "key.tz", "Saa za Eneo" },
             { "AL", "Albania" },
             { "AM", "Armenia" },
             { "AO", "Angola" },
@@ -163,11 +160,11 @@ public class LocaleNames_sw extends OpenListResourceBundle {
             { "CO", "Kolombia" },
             { "CP", "Kisiwa cha Clipperton" },
             { "CR", "Kostarika" },
-            { "CU", "Cuba" },
+            { "CU", "Kuba" },
             { "CV", "Cape Verde" },
             { "CW", "Curacao" },
             { "CX", "Kisiwa cha Krismasi" },
-            { "CY", "Cyprus" },
+            { "CY", "Saiprasi" },
             { "CZ", "Chechia" },
             { "eka", "Kiekajuk" },
             { "DE", "Ujerumani" },
@@ -176,9 +173,9 @@ public class LocaleNames_sw extends OpenListResourceBundle {
             { "DG", "Diego Garcia" },
             { "type.nu.deva", "Nambari za Kidevanagari" },
             { "DJ", "Jibuti" },
-            { "DK", "Denmark" },
+            { "DK", "Denmaki" },
             { "ach", "Kiakoli" },
-            { "Brai", "Braille" },
+            { "Brai", "Nukta nundu" },
             { "DM", "Dominika" },
             { "type.nu.armnlow", "Nambari Ndogo za Kiarmenia" },
             { "DO", "Jamhuri ya Dominika" },
@@ -206,19 +203,18 @@ public class LocaleNames_sw extends OpenListResourceBundle {
             { "ET", "Ethiopia" },
             { "EU", "Umoja wa Ulaya" },
             { "type.ca.gregorian", "Kalenda ya Kigregori" },
-            { "EZ", "EZ" },
+            { "EZ", "Jumuiya ya Ulaya" },
             { "chy", "Kicheyeni" },
             { "type.nu.gujr", "Nambari za Kigujarati" },
             { "ady", "Kiadyghe" },
             { "FI", "Ufini" },
             { "FJ", "Fiji" },
             { "FK", "Visiwa vya Falkland" },
-            { "FM", "Micronesia" },
-            { "key.va", "Tofauti ya Mandhari" },
+            { "FM", "Mikronesia" },
+            { "key.va", "Lahaja za Lugha" },
             { "FO", "Visiwa vya Faroe" },
             { "Taml", "Kitamil" },
             { "FR", "Ufaransa" },
-            { "root", "Kiroot" },
             { "type.ca.indian", "Kalenda ya Taifa ya India" },
             { "grc", "Kiyunani" },
             { "GA", "Gabon" },
@@ -240,6 +236,7 @@ public class LocaleNames_sw extends OpenListResourceBundle {
             { "GT", "Guatemala" },
             { "GU", "Guam" },
             { "GW", "Ginebisau" },
+            { "rhg", "Kirohingya" },
             { "tlh", "Kiklingoni" },
             { "GY", "Guyana" },
             { "ckb", "Kikurdi cha Sorani" },
@@ -327,12 +324,12 @@ public class LocaleNames_sw extends OpenListResourceBundle {
             { "MH", "Visiwa vya Marshall" },
             { "ale", "Kialeut" },
             { "type.nu.vaii", "Dijiti za Vai" },
-            { "MK", "Macedonia" },
+            { "MK", "Masedonia ya Kaskazini" },
             { "ML", "Mali" },
             { "MM", "Myanmar (Burma)" },
             { "MN", "Mongolia" },
             { "new", "Kinewari" },
-            { "MO", "Macau SAR China" },
+            { "MO", "Makau SAR China" },
             { "MP", "Visiwa vya Mariana vya Kaskazini" },
             { "MQ", "Martinique" },
             { "MR", "Moritania" },
@@ -341,14 +338,14 @@ public class LocaleNames_sw extends OpenListResourceBundle {
             { "type.m0.ungegn", "Mtindo wa kunukuu wa UN GEGN" },
             { "MU", "Morisi" },
             { "alt", "Kialtai" },
-            { "MV", "Maldives" },
+            { "MV", "Maldivi" },
             { "MW", "Malawi" },
             { "MX", "Meksiko" },
             { "type.ca.japanese", "Kalenda ya Kijapani" },
             { "MY", "Malesia" },
             { "MZ", "Msumbiji" },
             { "NA", "Namibia" },
-            { "202", "Afrika Kusine mwa Jangwa la Sahara" },
+            { "202", "Afrika ya Kusini mwa Jangwa la Sahara" },
             { "type.ca.hebrew", "Kalenda ya Kiebrania" },
             { "type.co.dictionary", "Mpangilio wa Kamusi" },
             { "NC", "New Caledonia" },
@@ -407,7 +404,7 @@ public class LocaleNames_sw extends OpenListResourceBundle {
             { "RW", "Rwanda" },
             { "SA", "Saudia" },
             { "SB", "Visiwa vya Solomon" },
-            { "twq", "Kitasawaq" },
+            { "twq", "Kitasawak" },
             { "011", "Afrika ya Magharibi" },
             { "SC", "Ushelisheli" },
             { "SD", "Sudan" },
@@ -434,17 +431,17 @@ public class LocaleNames_sw extends OpenListResourceBundle {
             { "type.nu.taml", "Nambari za Kitamil cha Jadi" },
             { "SR", "Suriname" },
             { "SS", "Sudan Kusini" },
-            { "ST", "S\u00e3o Tom\u00e9 na Pr\u00edncipe" },
+            { "ST", "Sao Tome na Principe" },
             { "arq", "Kiarabu cha Algeria" },
             { "SV", "El Salvador" },
             { "SX", "Sint Maarten" },
             { "SY", "Syria" },
             { "yao", "Kiyao" },
-            { "SZ", "Uswazi" },
+            { "SZ", "Eswatini" },
             { "arz", "Kiarabu cha Misri" },
             { "TA", "Tristan da Cunha" },
             { "asa", "Kiasu" },
-            { "type.ms.ussystem", "Mfumo wa US" },
+            { "type.ms.ussystem", "Mfumo wa Vipimo wa Marekani" },
             { "021", "Amerika ya Kaskazini" },
             { "TC", "Visiwa vya Turks na Caicos" },
             { "yav", "Kiyangben" },
@@ -495,7 +492,7 @@ public class LocaleNames_sw extends OpenListResourceBundle {
             { "VE", "Venezuela" },
             { "VG", "Visiwa vya Virgin, Uingereza" },
             { "VI", "Visiwa vya Virgin, Marekani" },
-            { "VN", "Vietnam" },
+            { "VN", "Vietnamu" },
             { "VU", "Vanuatu" },
             { "nog", "Kinogai" },
             { "rwk", "Lugha ya Rwa" },
@@ -510,7 +507,9 @@ public class LocaleNames_sw extends OpenListResourceBundle {
             { "wae", "Kiwalser" },
             { "WS", "Samoa" },
             { "wal", "Kiwolaytta" },
+            { "XA", "Lafudhi Bandia" },
             { "war", "Kiwaray" },
+            { "XB", "Lafudhi Bidi" },
             { "awa", "Kiawadhi" },
             { "061", "Polynesia" },
             { "XK", "Kosovo" },
@@ -609,7 +608,7 @@ public class LocaleNames_sw extends OpenListResourceBundle {
             { "type.nu.laoo", "Nambari za Kilao" },
             { "seh", "Kisena" },
             { "ca", "Kikatalani" },
-            { "ses", "Koyraboro Senni" },
+            { "ses", "Kikoyraboro Senni" },
             { "ce", "Kichechenia" },
             { "ch", "Kichamorro" },
             { "co", "Kikosikani" },
@@ -636,13 +635,14 @@ public class LocaleNames_sw extends OpenListResourceBundle {
             { "ee", "Kiewe" },
             { "bfd", "Kibafut" },
             { "type.lb.normal", "Mtindo wa Kawaida wa Kukata Mstari" },
+            { "ro_MD", "Kimoldova cha Romania" },
             { "el", metaValue_el },
             { "en", "Kiingereza" },
             { "eo", "Kiesperanto" },
             { "type.co.big5han", "Mpangilio wa Kichina cha Jadi - Big5" },
             { "es", "Kihispania" },
             { "et", "Kiestonia" },
-            { "Hanb", "Hanb" },
+            { "Hanb", "Kihan chenye Bopomofo" },
             { "eu", "Kibaski" },
             { "Hang", "Kihangul" },
             { "shi", "Kitachelhit" },
@@ -651,7 +651,7 @@ public class LocaleNames_sw extends OpenListResourceBundle {
             { "shn", "Kishan" },
             { "fa", "Kiajemi" },
             { "Hans", "Rahisi" },
-            { "type.nu.latn", "Nambari za Magharibi" },
+            { "type.nu.latn", "Nambari za Nchi za Magharibi" },
             { "Hant", "Cha jadi" },
             { "ff", "Kifulani" },
             { "shu", "Kiarabu cha Chad" },
@@ -670,7 +670,7 @@ public class LocaleNames_sw extends OpenListResourceBundle {
             { "gl", "Kigalisi" },
             { "gn", "Kiguarani" },
             { "bho", "Kibhojpuri" },
-            { "und", "Lugha Isiyojulikana" },
+            { "und", "Lugha isiyojulikana" },
             { "type.ca.ethiopic-amete-alem", "Kalenda ya Kiethiopia ya Amete Alem" },
             { "gu", metaValue_gu },
             { "gv", "Kimanx" },
@@ -679,7 +679,7 @@ public class LocaleNames_sw extends OpenListResourceBundle {
             { "hi", "Kihindi" },
             { "hup", "Hupa" },
             { "bin", "Kibini" },
-            { "hr", "Kikroeshia" },
+            { "hr", "Kikorasia" },
             { "ht", "Kihaiti" },
             { "hu", "Kihungaria" },
             { "hy", metaValue_hy },
@@ -700,6 +700,7 @@ public class LocaleNames_sw extends OpenListResourceBundle {
             { "iu", "Kiinuktituti" },
             { "ja", metaValue_ja },
             { "Mlym", "Kimalayalam" },
+            { "doi", "Kidogri" },
             { "bkm", "Kikom" },
             { "sma", "Kisami cha Kusini" },
             { "jv", "Kijava" },
@@ -738,7 +739,7 @@ public class LocaleNames_sw extends OpenListResourceBundle {
             { "ln", "Kilingala" },
             { "fur", "Kifriulian" },
             { "lo", metaValue_lo },
-            { "type.ms.uksystem", "Mfumo wa UK" },
+            { "type.ms.uksystem", "Mfumo wa Vipimo wa Uingereza" },
             { "lt", "Kilithuania" },
             { "lu", "Kiluba-Katanga" },
             { "lv", "Kilatvia" },
@@ -791,6 +792,7 @@ public class LocaleNames_sw extends OpenListResourceBundle {
             { "ps", "Kipashto" },
             { "pt", "Kireno" },
             { "key.co", "Mpangilio" },
+            { "pt_BR", "Kireno (Brazili)" },
             { "kcg", "Kityap" },
             { "mgh", "Kimakhuwa-Meetto" },
             { "key.cf", "Mpangilio wa Sarafu" },
@@ -883,9 +885,9 @@ public class LocaleNames_sw extends OpenListResourceBundle {
             { "uz", "Kiuzbeki" },
             { "kha", "Kikhasi" },
             { "ve", "Kivenda" },
-            { "type.ca.roc", "Kalenda ya Minguo" },
+            { "type.ca.roc", "Kalenda ya Jamhuri ya Uchina" },
             { "vi", "Kivietinamu" },
-            { "khq", "Koyra Chiini" },
+            { "khq", "Kikoyra Chiini" },
             { "key.hc", "Kipindi cha saa (12 au 24)" },
             { "vo", "Kivolapuk" },
             { "quc", "K\u02bciche\u02bc" },
@@ -931,17 +933,18 @@ public class LocaleNames_sw extends OpenListResourceBundle {
             { "kok", "Kikonkani" },
             { "zh_Hant", "Kichina cha Jadi" },
             { "kpe", "Kikpelle" },
-            { "type.nu.khmr", "Nambari za Kikhmer" },
+            { "type.nu.khmr", "Nambari za Kikambodia" },
             { "ilo", "Kiilocano" },
             { "mua", "Kimundang" },
             { "type.nu.guru", "Nambari za Kigurmukhi" },
-            { "mul", "Lugha Nyingi" },
+            { "mul", "Lugha nyingi" },
             { "key.ms", "Mfumo wa Vipimo" },
             { "mus", "Kikriki" },
             { "gil", "Kikiribati" },
             { "type.nu.tamldec", "Nambari za Kitamil" },
             { "krc", "Kikarachay-Balkar" },
             { "inh", "Kiingush" },
+            { "fa_AF", "Kiajemi (Afganistani)" },
             { "krl", "Karjala" },
             { "efi", "Kiefik" },
             { "key.nu", "Nambari" },
