@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -266,14 +266,6 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
                "heure de l\u2019Arm\u00e9nie",
                "",
             };
-        final String[] ETC_UTC = new String[] {
-               "temps universel coordonn\u00e9",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Georgia = new String[] {
                "heure normale de la G\u00e9orgie",
                "",
@@ -482,6 +474,14 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
                "heure du Cap-Vert",
                "",
             };
+        final String[] EMPTY_ZONE = new String[] {
+               "",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Uzbekistan = new String[] {
                "heure normale de l\u2019Ouzb\u00e9kistan",
                "",
@@ -755,7 +755,7 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "Asia/Tokyo", Japan },
             { "Europe/Bucharest", Europe_Eastern },
             { "Asia/Shanghai", China },
-            { "UTC", ETC_UTC },
+            { "UTC", EMPTY_ZONE },
             { "ACT", Australia_Central },
             { "AET", Australia_Eastern },
             { "ART", Europe_Eastern },
@@ -778,7 +778,6 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "PST", America_Pacific },
             { "CST6CDT", America_Central },
             { "EST5EDT", America_Eastern },
-            { "Etc/UTC", ETC_UTC },
             { "MST7MDT", America_Mountain },
             { "PST8PDT", America_Pacific },
             { "Asia/Aden", Arabian },
@@ -792,7 +791,7 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Asia/Anadyr", Anadyr },
             { "Asia/Beirut", Europe_Eastern },
             { "Asia/Harbin", China },
@@ -901,7 +900,6 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Mountain },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
             { "America/Juneau", Alaska },
@@ -959,7 +957,7 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "America/Moncton", Atlantic },
             { "America/Nipigon", America_Eastern },
             { "America/Noronha", Noronha },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Ojinaga", America_Central },
             { "America/Tijuana", America_Pacific },
             { "America/Toronto", America_Eastern },
             { "America/Tortola", Atlantic },
@@ -1030,7 +1028,7 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "America/Araguaina", Brasilia },
             { "America/Boa_Vista", Amazon },
             { "America/Catamarca", Argentina },
-            { "America/Chihuahua", Mexico_Pacific },
+            { "America/Chihuahua", America_Central },
             { "America/Fortaleza", Brasilia },
             { "America/Glace_Bay", Atlantic },
             { "America/Goose_Bay", Atlantic },
@@ -1065,7 +1063,6 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "America/Montserrat", Atlantic },
             { "America/Rio_Branco", Acre },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Mountain },
             { "Antarctica/McMurdo", New_Zealand },
             { "Asia/Yekaterinburg", Yekaterinburg },
             { "Atlantic/Jan_Mayen", Europe_Central },
